@@ -42,71 +42,71 @@ namespace Ogre {
         class _OgrePrivate CmdBorderSize : public ParamCommand
         {
         public:
-            String doGet(const void* target) const;
-            void doSet(void* target, const String& val);
+            String doGet(const void* target) const override;
+            void doSet(void* target, const String& val) override;
         };
         /** Command object for specifying the Material for the border (see ParamCommand).*/
         class _OgrePrivate CmdBorderMaterial : public ParamCommand
         {
         public:
-            String doGet(const void* target) const;
-            void doSet(void* target, const String& val);
+            String doGet(const void* target) const override;
+            void doSet(void* target, const String& val) override;
         };
         /** Command object for specifying texture coordinates for the border (see ParamCommand).*/
         class _OgrePrivate CmdBorderLeftUV : public ParamCommand
         {
         public:
-            String doGet(const void* target) const;
-            void doSet(void* target, const String& val);
+            String doGet(const void* target) const override;
+            void doSet(void* target, const String& val) override;
         };
         /** Command object for specifying texture coordinates for the border (see ParamCommand).*/
         class _OgrePrivate CmdBorderTopUV : public ParamCommand
         {
         public:
-            String doGet(const void* target) const;
-            void doSet(void* target, const String& val);
+            String doGet(const void* target) const override;
+            void doSet(void* target, const String& val) override;
         };
         /** Command object for specifying texture coordinates for the border (see ParamCommand).*/
         class _OgrePrivate CmdBorderRightUV : public ParamCommand
         {
         public:
-            String doGet(const void* target) const;
-            void doSet(void* target, const String& val);
+            String doGet(const void* target) const override;
+            void doSet(void* target, const String& val) override;
         };
         /** Command object for specifying texture coordinates for the border (see ParamCommand).*/
         class _OgrePrivate CmdBorderBottomUV : public ParamCommand
         {
         public:
-            String doGet(const void* target) const;
-            void doSet(void* target, const String& val);
+            String doGet(const void* target) const override;
+            void doSet(void* target, const String& val) override;
         };
         /** Command object for specifying texture coordinates for the border (see ParamCommand).*/
         class _OgrePrivate CmdBorderTopLeftUV : public ParamCommand
         {
         public:
-            String doGet(const void* target) const;
-            void doSet(void* target, const String& val);
+            String doGet(const void* target) const override;
+            void doSet(void* target, const String& val) override;
         };
         /** Command object for specifying texture coordinates for the border (see ParamCommand).*/
         class _OgrePrivate CmdBorderBottomLeftUV : public ParamCommand
         {
         public:
-            String doGet(const void* target) const;
-            void doSet(void* target, const String& val);
+            String doGet(const void* target) const override;
+            void doSet(void* target, const String& val) override;
         };
         /** Command object for specifying texture coordinates for the border (see ParamCommand).*/
         class _OgrePrivate CmdBorderBottomRightUV : public ParamCommand
         {
         public:
-            String doGet(const void* target) const;
-            void doSet(void* target, const String& val);
+            String doGet(const void* target) const override;
+            void doSet(void* target, const String& val) override;
         };
         /** Command object for specifying texture coordinates for the border (see ParamCommand).*/
         class _OgrePrivate CmdBorderTopRightUV : public ParamCommand
         {
         public:
-            String doGet(const void* target) const;
-            void doSet(void* target, const String& val);
+            String doGet(const void* target) const override;
+            void doSet(void* target, const String& val) override;
         };
         // Command objects
         static CmdBorderSize msCmdBorderSize;
@@ -257,10 +257,7 @@ namespace Ogre {
         if(!mInitialised)
             return;
 
-        VertexBufferBinding* bind = mRenderOp2.vertexData->vertexBufferBinding;
-        bind->unsetBinding(POSITION_BINDING);
-        bind->unsetBinding(TEXCOORD_BINDING);
-
+        mRenderOp2.vertexData->vertexBufferBinding->unsetAllBindings();
         mRenderOp2.indexData->indexBuffer.reset();
 
         PanelOverlayElement::_releaseManualHardwareResources();
@@ -612,7 +609,7 @@ namespace Ogre {
         */
         // Convert positions into -1, 1 coordinate space (homogenous clip space)
         // Top / bottom also need inverting since y is upside down
-        Real left[8], right[8], top[8], bottom[8];
+        float left[8], right[8], top[8], bottom[8];
         // Horizontal
         left[0] = left[3] = left[5] = _getDerivedLeft() * 2 - 1;
         left[1] = left[6] = right[0] = right[3] = right[5] = left[0] + (mLeftBorderSize * 2);
@@ -631,7 +628,7 @@ namespace Ogre {
         float* pPos = static_cast<float*>(vbufLock.pData);
         // Use the furthest away depth value, since materials should have depth-check off
         // This initialised the depth buffer for any 3D objects in front
-        Real zValue = Root::getSingleton().getRenderSystem()->getMaximumDepthInputValue();
+        float zValue = Root::getSingleton().getRenderSystem()->getMaximumDepthInputValue();
         for (ushort cell = 0; cell < 8; ++cell)
         {
             /*
