@@ -67,7 +67,9 @@ public:
         /// Binormal (Y axis if normal is Z)
         SPS_BINORMAL = 8,
         /// Tangent (X axis if normal is Z)
-        SPS_TANGENT = 9
+        SPS_TANGENT = 9,
+        /// VFACE
+        SPS_FRONT_FACING
     };
 
     /** Shader parameter content
@@ -303,6 +305,9 @@ public:
         /// point sprite size
         SPC_POINTSPRITE_SIZE,
 
+        /// gl_FrontFacing
+        SPC_FRONT_FACING,
+
         /// Reserved custom content range to be used by user custom shader extensions.
         SPC_CUSTOM_CONTENT_BEGIN    = 1000,
         SPC_CUSTOM_CONTENT_END      = 2000
@@ -370,6 +375,10 @@ public:
     void setUsed(bool used) { mUsed = used; }
     bool isUsed() { return mUsed; }
 
+    /// Is highp needed when using GLSL ES
+    bool isHighP() const { return mIsHighP; }
+    void setHighP(bool highP) { mIsHighP = highP; }
+
 // Attributes.
 protected:
     // Name of this parameter.
@@ -390,6 +399,7 @@ protected:
     size_t mSize;
     
     bool mUsed;
+    bool mIsHighP;
 };
 
 typedef ShaderParameterList::iterator           ShaderParameterIterator;
@@ -447,7 +457,7 @@ public:
 
     
     /** Get auto constant int data of this parameter, in case it is auto constant parameter. */
-    uint32 getAutoConstantIntData() const { return mAutoConstantIntData; }
+    uint32 getAutoConstantIntData() const { return isArray() ? getSize() : mAutoConstantIntData; }
 
     /** Get auto constant real data of this parameter, in case it is auto constant parameter. */
     float getAutoConstantRealData() const { return mAutoConstantRealData; }
@@ -643,12 +653,12 @@ public:
     /** 
     @see Parameter::isConstParameter.
     */
-    virtual bool isConstParameter() const { return true; }
+    bool isConstParameter() const override { return true; }
 
     /** 
     @see Parameter::toString.
     */
-    virtual String toString() const = 0;
+    String toString() const override = 0;
 
 protected:
     valueType mValue;
