@@ -40,7 +40,7 @@ bool CookTorranceLighting::createCpuSubPrograms(ProgramSet* programSet)
     ParameterPtr vsInTexcoord;
     if(!vsOutTexcoord)
     {
-        vsInTexcoord = vsMain->getInputParameter(Parameter::SPC_TEXTURE_COORDINATE0, GCT_FLOAT2);
+        vsInTexcoord = vsMain->resolveInputParameter(Parameter::SPC_TEXTURE_COORDINATE0, GCT_FLOAT2);
         vsOutTexcoord = vsMain->resolveOutputParameter(Parameter::SPC_TEXTURE_COORDINATE0, GCT_FLOAT2);
     }
     auto psInTexcoord = psMain->resolveInputParameter(vsOutTexcoord);
