@@ -43,9 +43,9 @@ public:
     /**
     Listener overridden function notify the shader generator when rendering single object.
     */
-    virtual void notifyRenderSingleObject(Renderable* rend, const Pass* pass,
+    void notifyRenderSingleObject(Renderable* rend, const Pass* pass,
                                           const AutoParamDataSource* source, const LightList* pLightList,
-                                          bool suppressRenderStateChanges)
+                                          bool suppressRenderStateChanges) override
     {
         mOwner->notifyRenderSingleObject(rend, pass, source, pLightList, suppressRenderStateChanges);
     }
@@ -63,8 +63,8 @@ public:
     /**
     Listener overridden function notify the shader generator when finding visible objects process started.
     */
-    virtual void preFindVisibleObjects(SceneManager* source, SceneManager::IlluminationRenderStage irs,
-                                       Viewport* v)
+    void preFindVisibleObjects(SceneManager* source, SceneManager::IlluminationRenderStage irs,
+                                       Viewport* v) override
     {
         mOwner->preFindVisibleObjects(source, irs, v);
     }
@@ -80,7 +80,7 @@ public:
     SGScriptTranslatorManager(ShaderGenerator* owner) { mOwner = owner; }
 
     /// Returns a manager for the given object abstract node, or null if it is not supported
-    virtual ScriptTranslator* getTranslator(const AbstractNodePtr& node)
+    ScriptTranslator* getTranslator(const AbstractNodePtr& node) override
     {
         return mOwner->getTranslator(node);
     }
@@ -96,7 +96,7 @@ public:
     SGResourceGroupListener(ShaderGenerator* owner) { mOwner = owner; }
 
     /// sync our internal list if material gets dropped
-    virtual void resourceRemove(const ResourcePtr& resource)
+    void resourceRemove(const ResourcePtr& resource) override
     {
         if (auto mat = dynamic_cast<Material*>(resource.get()))
         {
@@ -197,11 +197,6 @@ bool ShaderGenerator::_initialize()
     // Allocate program manager.
     mProgramManager.reset(new ProgramManager);
 
-    // Allocate and initialize FFP render state builder.
-#ifdef RTSHADER_SYSTEM_BUILD_CORE_SHADERS
-    mFFPRenderStateBuilder.reset(new FFPRenderStateBuilder);
-#endif
-
     // Create extensions factories.
     createBuiltinSRSFactories();
 
@@ -340,10 +335,6 @@ void ShaderGenerator::_destroy()
     // Destroy extensions factories.
     destroyBuiltinSRSFactories();
 
-#ifdef RTSHADER_SYSTEM_BUILD_CORE_SHADERS
-    mFFPRenderStateBuilder.reset();
-#endif
-
     mProgramManager.reset();
     mProgramWriterManager.reset();
 
@@ -1445,6 +1436,16 @@ ShaderGenerator::SGPass::~SGPass()
 }
 
 //-----------------------------------------------------------------------------
+#ifdef RTSHADER_SYSTEM_BUILD_CORE_SHADERS
+static void addDefaultSubRenderStates(const TargetRenderStatePtr& renderState, Pass* srcPass, Pass* dstPass)
+{
+    RenderState ffpTemplate;
+    ffpTemplate.addTemplateSubRenderStates(
+        {SRS_TRANSFORM, SRS_VERTEX_COLOUR, SRS_PER_PIXEL_LIGHTING, SRS_TEXTURING, SRS_FOG, SRS_ALPHA_TEST});
+    renderState->link(ffpTemplate, srcPass, dstPass);
+}
+#endif
+
 void ShaderGenerator::SGPass::buildTargetRenderState()
 {   
     if(mSrcPass->isProgrammable() && !mParent->overProgrammablePass() && !isIlluminationPass()) return;
@@ -1485,8 +1486,7 @@ void ShaderGenerator::SGPass::buildTargetRenderState()
     }
 
 #ifdef RTSHADER_SYSTEM_BUILD_CORE_SHADERS
-    // Build the FFP state.
-    FFPRenderStateBuilder::buildRenderState(this, targetRenderState.get());
+    addDefaultSubRenderStates(targetRenderState, mSrcPass, mDstPass);
 #endif
 
     targetRenderState->acquirePrograms(mDstPass);
