@@ -54,7 +54,7 @@ namespace RTShader {
         /** 
         @see Parameter::toString.
         */
-        virtual String toString () const
+        String toString () const override
         {
             StringStream str;
             str << "vec2(" << std::showpoint << mValue.x << "," << mValue.y << ")";
@@ -79,7 +79,7 @@ namespace RTShader {
         /** 
         @see Parameter::toString.
         */
-        virtual String toString () const
+        String toString () const override
         {
             StringStream str;
             str << "vec3(" << std::showpoint << mValue.x << "," << mValue.y << "," << mValue.z << ")";
@@ -104,7 +104,7 @@ namespace RTShader {
         /** 
         @see Parameter::toString.
         */
-        virtual String toString () const
+        String toString () const override
         {
             StringStream str;
             str << "vec4(" << std::showpoint << mValue.x << "," << mValue.y << "," << mValue.z << "," << mValue.w << ")";
@@ -130,7 +130,7 @@ namespace RTShader {
         /** 
         @see Parameter::toString.
         */
-        virtual String toString () const
+        String toString () const override
         {
             return StringConverter::toString(mValue, 6, 0, ' ', std::ios::showpoint);
         }
@@ -153,14 +153,14 @@ namespace RTShader {
         /** 
         @see Parameter::toString.
         */
-        virtual String toString () const
+        String toString () const override
         {
             return Ogre::StringConverter::toString(mValue);
         }
     };
 
 //-----------------------------------------------------------------------
-Parameter::Parameter() : mName(""), mType(GCT_UNKNOWN), mSemantic(SPS_UNKNOWN), mIndex(0), mContent(SPC_UNKNOWN), mSize(0), mUsed(false)
+Parameter::Parameter() : mName(""), mType(GCT_UNKNOWN), mSemantic(SPS_UNKNOWN), mIndex(0), mContent(SPC_UNKNOWN), mSize(0), mUsed(false), mIsHighP(false)
 {
 }
 
@@ -168,7 +168,7 @@ Parameter::Parameter() : mName(""), mType(GCT_UNKNOWN), mSemantic(SPS_UNKNOWN),
 Parameter::Parameter(GpuConstantType type, const String& name, 
             const Semantic& semantic, int index, 
             const Content& content, size_t size) :
-    mName(name), mType(type), mSemantic(semantic), mIndex(index), mContent(content), mSize(size), mUsed(false)
+    mName(name), mType(type), mSemantic(semantic), mIndex(index), mContent(content), mSize(size), mUsed(false), mIsHighP(false)
 {
 }
 
@@ -180,6 +180,7 @@ UniformParameter::UniformParameter(GpuConstantType type, const String& name,
 {
     mIsAutoConstantReal     = false;    
     mIsAutoConstantInt      = false;
+    mIsHighP                = false;
     mAutoConstantIntData    = 0;
     mVariability            = variability;
     mParamsPtr              = NULL;
