@@ -59,16 +59,6 @@ namespace Ogre
         mLayerDecl.samplers.push_back(TerrainLayerSampler("albedo_specular", PF_BYTE_RGBA));
         mLayerDecl.samplers.push_back(TerrainLayerSampler("normal_height", PF_BYTE_RGBA));
         
-        mLayerDecl.elements.push_back(
-            TerrainLayerSamplerElement(0, TLSS_ALBEDO, 0, 3));
-        mLayerDecl.elements.push_back(
-            TerrainLayerSamplerElement(0, TLSS_SPECULAR, 3, 1));
-        mLayerDecl.elements.push_back(
-            TerrainLayerSamplerElement(1, TLSS_NORMAL, 0, 3));
-        mLayerDecl.elements.push_back(
-            TerrainLayerSamplerElement(1, TLSS_HEIGHT, 3, 1));
-
-
         mProfiles.push_back(OGRE_NEW SM2Profile(this, "SM2", "Profile for rendering on Shader Model 2 capable cards"));
 
         // TODO - check hardware capabilities & use fallbacks if required (more profiles needed)
@@ -253,17 +243,14 @@ namespace Ogre
         
         // Automatically disable normal & parallax mapping if card cannot handle it
         // We do this rather than having a specific technique for it since it's simpler
-        GpuProgramManager& gmgr = GpuProgramManager::getSingleton();
-        if (!gmgr.isSyntaxSupported("ps_4_0") && !gmgr.isSyntaxSupported("ps_3_0") && !gmgr.isSyntaxSupported("ps_2_x")
-            && !gmgr.isSyntaxSupported("fp40") && !gmgr.isSyntaxSupported("arbfp1") && !gmgr.isSyntaxSupported("glsl")
-            && !gmgr.isSyntaxSupported("glsles"))
+        auto rsc = Root::getSingletonPtr()->getRenderSystem()->getCapabilities();
+        if (rsc->getNumTextureUnits() < 9)
         {
             setLayerNormalMappingEnabled(false);
             setLayerParallaxMappingEnabled(false);
         }
 
         addTechnique(mat, terrain, HIGH_LOD);
-        updateParams(mat, terrain);
 
         // LOD
         if(mCompositeMapEnabled)
@@ -312,6 +299,8 @@ namespace Ogre
             mat->setLodLevels({TerrainGlobalOptions::getSingleton().getCompositeMapDistance()});
         }
 
+        updateParams(mat, terrain);
+
         return mat;
     }
     //---------------------------------------------------------------------
@@ -439,6 +428,17 @@ namespace Ogre
         Pass* p = mat->getTechnique(0)->getPass(0);
         mShaderGen->updateVpParams(this, terrain, HIGH_LOD, p->getVertexProgramParameters());
         mShaderGen->updateFpParams(this, terrain, HIGH_LOD, p->getFragmentProgramParameters());
+
+        if(!isCompositeMapEnabled())
+            return;
+
+        using namespace RTShader;
+        auto lod1RenderState = any_cast<TargetRenderStatePtr>(
+            mat->getTechnique(1)->getPass(0)->getUserObjectBindings().getUserAny(TargetRenderState::UserKey));
+        if (auto transform = lod1RenderState->getSubRenderState("TerrainTransform"))
+        {
+            static_cast<TerrainTransform*>(transform)->updateParams();
+        }
     }
     //---------------------------------------------------------------------
     void TerrainMaterialGeneratorA::SM2Profile::updateParamsForCompositeMap(const MaterialPtr& mat, const Terrain* terrain)
@@ -583,7 +583,7 @@ namespace Ogre
         }
 
         // Explicitly bind samplers for GLSL
-        if (mIsGLSL)
+        if (mLang == "glsl" || mLang == "glsles")
         {
             int numSamplers = 0;
             if (tt == LOW_LOD)
