@@ -89,7 +89,7 @@ namespace Ogre
     {
     public:
         typedef std::vector<InstancedEntity*>  InstancedEntityVec;
-        typedef std::vector<Vector4>           CustomParamsVec;
+        typedef std::vector<Vector4f>           CustomParamsVec;
     protected:
         typedef TransformBase<3, float>        Matrix3x4f;
         RenderOperation     mRenderOperation;
@@ -327,35 +327,35 @@ namespace Ogre
         void _markTransformSharingDirty() { mTransformSharingDirty = true; }
 
         /** @see InstancedEntity::setCustomParam */
-        void _setCustomParam( InstancedEntity *instancedEntity, unsigned char idx, const Vector4 &newParam );
+        void _setCustomParam( InstancedEntity *instancedEntity, unsigned char idx, const Vector4f &newParam );
 
         /** @see InstancedEntity::getCustomParam */
-        const Vector4& _getCustomParam( InstancedEntity *instancedEntity, unsigned char idx );
+        const Vector4f& _getCustomParam( InstancedEntity *instancedEntity, unsigned char idx );
 
         //Renderable overloads
         /** @copydoc Renderable::getMaterial */
-        const MaterialPtr& getMaterial(void) const      { return mMaterial; }
+        const MaterialPtr& getMaterial(void) const override      { return mMaterial; }
         /** @copydoc Renderable::getRenderOperation */
-        void getRenderOperation( RenderOperation& op )  { op = mRenderOperation; }
+        void getRenderOperation( RenderOperation& op ) override  { op = mRenderOperation; }
 
         /** @copydoc Renderable::getSquaredViewDepth */
-        Real getSquaredViewDepth( const Camera* cam ) const;
+        Real getSquaredViewDepth( const Camera* cam ) const override;
         /** @copydoc Renderable::getLights */
-        const LightList& getLights( void ) const;
+        const LightList& getLights( void ) const override;
         /** @copydoc Renderable::getTechnique */
-        Technique* getTechnique(void) const;
+        Technique* getTechnique(void) const override;
 
         /** @copydoc MovableObject::getMovableType */
-        const String& getMovableType(void) const;
+        const String& getMovableType(void) const override;
         /** @copydoc MovableObject::_notifyCurrentCamera */
-        void _notifyCurrentCamera( Camera* cam );
+        void _notifyCurrentCamera( Camera* cam ) override;
         /** @copydoc MovableObject::getBoundingBox */
-        const AxisAlignedBox& getBoundingBox(void) const;
+        const AxisAlignedBox& getBoundingBox(void) const override;
         /** @copydoc MovableObject::getBoundingRadius */
-        Real getBoundingRadius(void) const;
+        Real getBoundingRadius(void) const override;
 
-        virtual void _updateRenderQueue(RenderQueue* queue);
-        void visitRenderables( Renderable::Visitor* visitor, bool debugRenderables = false );
+        void _updateRenderQueue(RenderQueue* queue) override;
+        void visitRenderables( Renderable::Visitor* visitor, bool debugRenderables = false ) override;
 
         // resolve ambiguity of get/setUserAny due to inheriting from Renderable and MovableObject
         using Renderable::getUserAny;
