@@ -136,7 +136,7 @@ namespace Ogre {
         option on this texture to Ogre::FO_ANISOTROPIC.
         @param maxAniso
             The maximal anisotropy level, should be between 2 and the maximum
-            supported by hardware (1 is the default, ie. no anisotrophy).
+            supported by hardware (1 is the default, ie. no anisotropy).
         */
         void setAnisotropy(unsigned int maxAniso)
         {
@@ -262,17 +262,16 @@ namespace Ogre {
 
         };
 
-        /** Enumeration to specify type of envmap.
-        */
+        /// %Texture coordinate generation method for environment mapping.
         enum EnvMapType
         {
-            /// Envmap based on vector from camera to vertex position, good for planar geometry.
+            /// 2D texture coordinates using view space position. Same as ENV_CURVED on all backends.
             ENV_PLANAR,
-            /// Envmap based on dot of vector from camera to vertex and vertex normal, good for curves.
+            /// 2D texture coordinates using spherical reflection mapping
             ENV_CURVED,
-            /// Envmap intended to supply reflection vectors for cube mapping.
+            /// Cubic texture coordinates using the reflection vector
             ENV_REFLECTION,
-            /// Envmap intended to supply normal vectors for cube mapping.
+            /// Cubic texture coordinates using the normal vector
             ENV_NORMAL
         };
 
@@ -320,7 +319,7 @@ namespace Ogre {
             Real frequency;
             Real phase;
             Real amplitude;
-            Controller<Real>* controller;
+            ControllerReal* controller;
             const Frustum* frustum;
         };
 
@@ -350,7 +349,7 @@ namespace Ogre {
         TextureUnitState( Pass* parent, const String& texName, unsigned int texCoordSet = 0);
 
         /** Get the name of current texture image for this layer.
-        @remarks
+
             This will either always be a single name for this layer,
             or will be the name of the current frame for an animated
             or otherwise multi-frame texture.
@@ -505,7 +504,7 @@ namespace Ogre {
         OGRE_DEPRECATED BindingType getBindingType(void) const;
 
         /** Set the type of content this TextureUnitState references.
-        @remarks
+
             The default is to reference a standard named texture, but this unit
             can also reference automated content like a shadow texture.
         */
@@ -863,13 +862,13 @@ namespace Ogre {
             Real manualBlend = 0.0);
 
         /** Generic method for setting up texture effects.
-        @remarks
-            Allows you to specify effects directly by using the TextureEffectType enumeration. The
+
+            Allows you to specify effects directly by using the #TextureEffectType enumeration. The
             arguments that go with it depend on the effect type. Only one effect of
             each type can be applied to a texture layer.
         @par
             This method is used internally by Ogre but it is better generally for applications to use the
-            more intuitive specialised methods such as setEnvironmentMap and setScroll.
+            more intuitive specialised methods such as #setEnvironmentMap and #setTextureScroll.
         */
         void addEffect(TextureEffect& effect);
 
@@ -880,9 +879,7 @@ namespace Ogre {
 
             The vectors generated can either be used to address a single 2D texture which
             is a 'fish-eye' lens view of a scene, or a 3D cubic environment map which requires 6 textures
-            for each side of the inside of a cube. The type depends on what texture you set up - if you use the
-            setTextureName method then a 2D fisheye lens texture is required, whereas if you used setCubicTextureName
-            then a cubic environment map will be used.
+            for each side of the inside of a cube.
 
             This effect works best if the object has lots of gradually changing normals. The texture also
             has to be designed for this effect - see the example spheremap.png included with the sample
@@ -894,10 +891,9 @@ namespace Ogre {
             generated coordinates rather than static model texture coordinates.
         @param enable
             True to enable, false to disable
-        @param envMapType
-            The type of environment mapping to perform. Planar, curved, reflection or normal. @see EnvMapType
+        @param texGenType texture coordinate generation type
         */
-        void setEnvironmentMap(bool enable, EnvMapType envMapType = ENV_CURVED);
+        void setEnvironmentMap(bool enable, EnvMapType texGenType = ENV_CURVED);
 
         /** Sets up an animated scroll for the texture layer.
 
@@ -939,7 +935,7 @@ namespace Ogre {
 
 
         /** Enables or disables projective texturing on this texture unit.
-        @remarks
+
             Projective texturing allows you to generate texture coordinates 
             based on a Frustum, which gives the impression that a texture is
             being projected onto the surface. Note that once you have called
@@ -1068,7 +1064,7 @@ namespace Ogre {
         /** Gets the animation controller (as created because of setAnimatedTexture)
             if it exists.
         */
-        Controller<Real>* _getAnimController() const { return mAnimController; }
+        ControllerReal* _getAnimController() const { return mAnimController; }
 
         /// return a sampler local to this TUS instead of the shared global one
         const SamplerPtr& _getLocalSampler();
@@ -1122,7 +1118,7 @@ private:
         // preserving even if assign from others
         //
         Pass* mParent;
-        Controller<Real>* mAnimController;
+        ControllerReal* mAnimController;
         //-----------------------------------------------------------------------------
 
 
