@@ -38,50 +38,50 @@ namespace Ogre {
     class _OgrePrivate CmdBillboardType : public ParamCommand
     {
     public:
-        String doGet(const void* target) const;
-        void doSet(void* target, const String& val);
+        String doGet(const void* target) const override;
+        void doSet(void* target, const String& val) override;
     };
     /** Command object for billboard origin (see ParamCommand).*/
     class _OgrePrivate CmdBillboardOrigin : public ParamCommand
     {
     public:
-        String doGet(const void* target) const;
-        void doSet(void* target, const String& val);
+        String doGet(const void* target) const override;
+        void doSet(void* target, const String& val) override;
     };
     /** Command object for billboard rotation type (see ParamCommand).*/
     class _OgrePrivate CmdBillboardRotationType : public ParamCommand
     {
     public:
-        String doGet(const void* target) const;
-        void doSet(void* target, const String& val);
+        String doGet(const void* target) const override;
+        void doSet(void* target, const String& val) override;
     };
     /** Command object for common direction (see ParamCommand).*/
     class _OgrePrivate CmdCommonDirection : public ParamCommand
     {
     public:
-        String doGet(const void* target) const;
-        void doSet(void* target, const String& val);
+        String doGet(const void* target) const override;
+        void doSet(void* target, const String& val) override;
     };
     /** Command object for common up-vector (see ParamCommand).*/
     class _OgrePrivate CmdCommonUpVector : public ParamCommand
     {
     public:
-        String doGet(const void* target) const;
-        void doSet(void* target, const String& val);
+        String doGet(const void* target) const override;
+        void doSet(void* target, const String& val) override;
     };
     /** Command object for point rendering (see ParamCommand).*/
     class _OgrePrivate CmdPointRendering : public ParamCommand
     {
     public:
-        String doGet(const void* target) const;
-        void doSet(void* target, const String& val);
+        String doGet(const void* target) const override;
+        void doSet(void* target, const String& val) override;
     };
     /** Command object for accurate facing(see ParamCommand).*/
     class _OgrePrivate CmdAccurateFacing : public ParamCommand
     {
     public:
-        String doGet(const void* target) const;
-        void doSet(void* target, const String& val);
+        String doGet(const void* target) const override;
+        void doSet(void* target, const String& val) override;
     };
     static CmdBillboardType msBillboardTypeCmd;
     static CmdBillboardOrigin msBillboardOriginCmd;
@@ -94,12 +94,12 @@ namespace Ogre {
     static class CmdStacksAndSlices : public ParamCommand
     {
     public:
-        String doGet(const void* target) const
+        String doGet(const void* target) const override
         {
             return StringConverter::toString(
                 static_cast<const BillboardParticleRenderer*>(target)->getTextureStacksAndSlices());
         }
-        void doSet(void* target, const String& val)
+        void doSet(void* target, const String& val) override
         {
             Vector2 tmp = StringConverter::parseVector2(val);
             static_cast<BillboardParticleRenderer*>(target)->setTextureStacksAndSlices(tmp.x, tmp.y);
@@ -248,12 +248,6 @@ namespace Ogre {
         return OGRE_NEW BillboardParticleRenderer();
     }
     //-----------------------------------------------------------------------
-    void BillboardParticleRendererFactory::destroyInstance( 
-        ParticleSystemRenderer* inst)
-    {
-        OGRE_DELETE  inst;
-    }
-    //-----------------------------------------------------------------------
     //-----------------------------------------------------------------------
     String CmdBillboardType::doGet(const void* target) const
     {
