@@ -37,6 +37,7 @@ THE SOFTWARE.
 #include "OgreRenderTarget.h"
 #include "OgreRenderTexture.h"
 #include "OgreRectangle2D.h"
+#include "OgreDepthBuffer.h"
 
 namespace Ogre {
 CompositorInstance::CompositorInstance(CompositionTechnique *technique,
@@ -45,6 +46,7 @@ CompositorInstance::CompositorInstance(CompositionTechnique *technique,
         mEnabled(false),
         mAlive(false)
 {
+    OgreAssert(mChain, "Undefined compositor chain");
     mEnabled = false;
     const String& logicName = mTechnique->getCompositorLogicName();
     if (!logicName.empty())
@@ -109,25 +111,24 @@ void CompositorInstance::setAlive(bool value)
 class RSClearOperation: public CompositorInstance::RenderSystemOperation
 {
 public:
-    RSClearOperation(uint32 inBuffers, ColourValue inColour, Real inDepth, unsigned short inStencil, bool inAutomaticColour):
-        buffers(inBuffers), colour(inColour), automaticColour(inAutomaticColour), depth(inDepth), stencil(inStencil)
+    RSClearOperation(uint32 inBuffers, ColourValue inColour, Real inDepth, unsigned short inStencil, CompositorChain *inChain):
+        chain(inChain), buffers(inBuffers), colour(inColour), depth(inDepth), stencil(inStencil)
     {}
+    /// Automatic colour from original viewport background colour
+    CompositorChain* chain;
     /// Which buffers to clear (FrameBufferType)
     uint32 buffers;
     /// Colour to clear in case FBT_COLOUR is set
     ColourValue colour;
-    /// Automatic colour from original viewport background colour
-    bool automaticColour;
     /// Depth to set in case FBT_DEPTH is set
     Real depth;
     /// Stencil value to set in case FBT_STENCIL is set
     unsigned short stencil;
 
-    virtual void execute(SceneManager *sm, RenderSystem *rs)
+    void execute(SceneManager *sm, RenderSystem *rs) override
     {
-        // _getViewport returns the viewport currently rendered, while getViewport returns lastViewport!
-        if((buffers & FBT_COLOUR) && automaticColour)
-          colour = rs->_getViewport()->getCamera()->getViewport()->getBackgroundColour();
+        if((buffers & FBT_COLOUR) && chain) // if chain is present, query colour from dst viewport
+          colour = chain->getViewport()->getBackgroundColour();
         rs->clearFrameBuffer(buffers, colour, depth, stencil);
     }
 };
@@ -137,27 +138,13 @@ public:
 class RSStencilOperation: public CompositorInstance::RenderSystemOperation
 {
 public:
-    RSStencilOperation(bool inStencilCheck, CompareFunction inFunc, uint32 inRefValue, uint32 inMask,
-        StencilOperation inStencilFailOp, StencilOperation inDepthFailOp, StencilOperation inPassOp,
-        bool inTwoSidedOperation, bool inReadBackAsTexture):
-        stencilCheck(inStencilCheck), func(inFunc), refValue(inRefValue), mask(inMask),
-        stencilFailOp(inStencilFailOp), depthFailOp(inDepthFailOp), passOp(inPassOp),
-        twoSidedOperation(inTwoSidedOperation), readBackAsTexture(inReadBackAsTexture)
-    {}
-    bool stencilCheck;
-    CompareFunction func; 
-    uint32 refValue;
-    uint32 mask;
-    StencilOperation stencilFailOp;
-    StencilOperation depthFailOp;
-    StencilOperation passOp;
-    bool twoSidedOperation;
-    bool readBackAsTexture;
+    RSStencilOperation(const StencilState& inState) : state(inState) {}
 
-    virtual void execute(SceneManager *sm, RenderSystem *rs)
+    StencilState state;
+
+    void execute(SceneManager *sm, RenderSystem *rs) override
     {
-        rs->setStencilCheckEnabled(stencilCheck);
-        rs->setStencilBufferParams(func, refValue, mask, 0xFFFFFFFF, stencilFailOp, depthFailOp, passOp, twoSidedOperation, readBackAsTexture);
+        rs->setStencilState(state);
     }
 };
 
@@ -197,7 +184,7 @@ public:
         mQuadFarCornersViewSpace = farCornersViewSpace;
     }
    
-    virtual void execute(SceneManager *sm, RenderSystem *rs)
+    void execute(SceneManager *sm, RenderSystem *rs) override
     {
         // Fire listener
         instance->_fireNotifyMaterialRender(pass_id, mat);
@@ -228,11 +215,10 @@ public:
         }
 
         // Queue passes from mat
-        Technique::Passes::const_iterator i;
-        for(i = technique->getPasses().begin(); i != technique->getPasses().end(); ++i)
+        for(auto *p : technique->getPasses())
         {
             sm->_injectRenderWithPass(
-                *i,
+                p,
                 rect,
                 false // don't allow replacement of shadow passes
                 );
@@ -252,7 +238,7 @@ public:
 
     String mSchemeName;
 
-    virtual void execute(SceneManager *sm, RenderSystem *rs)
+    void execute(SceneManager *sm, RenderSystem *rs) override
     {
         MaterialManager& matMgr = MaterialManager::getSingleton();
         mPreviousScheme = matMgr.getActiveScheme();
@@ -275,7 +261,7 @@ public:
     
     const RSSetSchemeOperation* mSetOperation;
 
-    virtual void execute(SceneManager *sm, RenderSystem *rs)
+    void execute(SceneManager *sm, RenderSystem *rs) override
     {
         MaterialManager::getSingleton().setActiveScheme(mSetOperation->getPreviousScheme());
         sm->setLateMaterialResolving(mSetOperation->getPreviousLateResolving());
@@ -298,7 +284,7 @@ public:
         technique = mat->getBestTechnique();
     }
 
-    void execute(SceneManager *sm, RenderSystem *rs)
+    void execute(SceneManager *sm, RenderSystem *rs) override
     {
         // Fire listener
         instance->_fireNotifyMaterialRender(pass_id, mat);
@@ -331,16 +317,12 @@ void CompositorInstance::collectPasses(TargetOperation &finalState, const Compos
                 pass->getClearBuffers(),
                 pass->getClearColour(),
                 pass->getClearDepth(),
-                (ushort)pass->getClearStencil(),
-                pass->getAutomaticColour()
+                pass->getClearStencil(),
+                pass->getAutomaticColour() ? mChain : NULL
                 ));
             break;
         case CompositionPass::PT_STENCIL:
-            queueRenderSystemOp(finalState, OGRE_NEW RSStencilOperation(
-                pass->getStencilCheck(),pass->getStencilFunc(), pass->getStencilRefValue(),
-                pass->getStencilMask(), pass->getStencilFailOp(), pass->getStencilDepthFailOp(),
-                pass->getStencilPassOp(), pass->getStencilTwoSidedOperation(), pass->getStencilReadBackAsTextureOperation()
-                ));
+            queueRenderSystemOp(finalState, OGRE_NEW RSStencilOperation(pass->getStencilState()));
             break;
         case CompositionPass::PT_RENDERSCENE: 
         {
@@ -378,6 +360,9 @@ void CompositorInstance::collectPasses(TargetOperation &finalState, const Compos
                     OGRE_NEW RSRestoreSchemeOperation(setSchemeOperation));
             }
 
+            finalState.cameraOverride = pass->getCameraName();
+            finalState.alignCameraToFace = pass->getAlignCameraToFace() ? target->getOutputSlice() : -1;
+
             finalState.findVisibleObjects = true;
 
             break;
@@ -406,10 +391,8 @@ void CompositorInstance::collectPasses(TargetOperation &finalState, const Compos
             /// Create local material
             MaterialPtr localMat = createLocalMaterial(srcmat->getName());
             /// Copy and adapt passes from source material
-            Technique::Passes::const_iterator i;
-            for(i = srctech->getPasses().begin(); i != srctech->getPasses().end(); ++i)
+            for(auto *srcpass : srctech->getPasses())
             {
-                Pass *srcpass = *i;
                 /// Create new target pass
                 targetpass = localMat->getTechnique(0)->createPass();
                 (*targetpass) = (*srcpass);
@@ -430,7 +413,7 @@ void CompositorInstance::collectPasses(TargetOperation &finalState, const Compos
                     {
                         if(x < targetpass->getNumTextureUnitStates())
                         {
-                            targetpass->getTextureUnitState((ushort)x)->setTextureName(getSourceForTex(inp.name, inp.mrtIndex));
+                            targetpass->getTextureUnitState((ushort)x)->setTexture(getSourceForTex(inp.name, inp.mrtIndex));
                         } 
                         else
                         {
@@ -483,7 +466,7 @@ void CompositorInstance::_compileTargetOperations(CompiledState &compiledState)
     /// Texture targets
     for (CompositionTargetPass *target : mTechnique->getTargetPasses())
     {        
-        TargetOperation ts(getTargetForTex(target->getOutputName()));
+        TargetOperation ts(getTargetForTex(target->getOutputName(), target->getOutputSlice()));
         /// Set "only initial" flag, visibilityMask and lodBias according to CompositionTargetPass.
         ts.onlyInitial = target->getOnlyInitial();
         ts.visibilityMask = target->getVisibilityMask();
@@ -526,16 +509,6 @@ void CompositorInstance::_compileOutputOperation(TargetOperation &finalState)
     collectPasses(finalState, tpass);
 }
 //-----------------------------------------------------------------------
-Compositor *CompositorInstance::getCompositor()
-{
-    return mCompositor;
-}
-//-----------------------------------------------------------------------
-CompositionTechnique *CompositorInstance::getTechnique()
-{
-    return mTechnique;
-}
-//-----------------------------------------------------------------------
 void CompositorInstance::setTechnique(CompositionTechnique* tech, bool reuseTextures)
 {
     if (mTechnique != tech)
@@ -546,10 +519,8 @@ void CompositorInstance::setTechnique(CompositionTechnique* tech, bool reuseText
             // this will ensure they don't get destroyed as unreferenced
             // so they're ready to use again later
             const CompositionTechnique::TextureDefinitions& tdefs = mTechnique->getTextureDefinitions();
-            CompositionTechnique::TextureDefinitions::const_iterator it = tdefs.begin();
-            for (; it != tdefs.end(); ++it)
+            for (auto *def : tdefs)
             {
-                CompositionTechnique::TextureDefinition *def = *it;
                 if (def->pooled)
                 {
                     LocalTextureMap::iterator i = mLocalTextures.find(def->name);
@@ -594,10 +565,10 @@ CompositorChain *CompositorInstance::getChain()
 const String& CompositorInstance::getTextureInstanceName(const String& name, 
                                                          size_t mrtIndex)
 {
-    return getSourceForTex(name, mrtIndex);
+    return getSourceForTex(name, mrtIndex)->getName();
 }
 //---------------------------------------------------------------------
-TexturePtr CompositorInstance::getTextureInstance(const String& name, size_t mrtIndex)
+const TexturePtr& CompositorInstance::getTextureInstance(const String& name, size_t mrtIndex)
 {
     // try simple textures first
     LocalTextureMap::iterator i = mLocalTextures.find(name);
@@ -614,7 +585,8 @@ TexturePtr CompositorInstance::getTextureInstance(const String& name, size_t mrt
     }
 
     // not present
-    return TexturePtr();
+    static TexturePtr nullPtr;
+    return nullPtr;
 
 }
 //-----------------------------------------------------------------------
@@ -648,18 +620,13 @@ void CompositorInstance::createResources(bool forResizeOnly)
     /// are composited.
     CompositorManager::UniqueTextureSet assignedTextures;
 
-    const CompositionTechnique::TextureDefinitions& tdefs = mTechnique->getTextureDefinitions();
-    CompositionTechnique::TextureDefinitions::const_iterator it = tdefs.begin();
-    for (; it != tdefs.end(); ++it)
+    for (auto def : mTechnique->getTextureDefinitions())
     {
-        CompositionTechnique::TextureDefinition *def = *it;
-        
         if (!def->refCompName.empty()) {
             //This is a reference, isn't created in this compositor
             continue;
         }
-        
-        RenderTarget* rendTarget;
+
         if (def->scope == CompositionTechnique::TS_GLOBAL) {
             //This is a global texture, just link the created resources from the parent
             Compositor* parentComp = mTechnique->getParent();
@@ -676,12 +643,13 @@ void CompositorInstance::createResources(bool forResizeOnly)
                 (parentComp->getRenderTarget(def->name));
                 mLocalMRTs[def->name] = mrt;
                 
-                rendTarget = mrt;
+                setupRenderTarget(mrt, def->depthBufferId);
             } else {
                 Ogre::TexturePtr tex = parentComp->getTextureInstance(def->name, 0);
                 mLocalTextures[def->name] = tex;
                 
-                rendTarget = tex->getBuffer()->getRenderTarget();
+                for(size_t i = 0; i < tex->getNumFaces(); i++)
+                    setupRenderTarget(tex->getBuffer(i)->getRenderTarget(), def->depthBufferId);
             }
             
         } else {
@@ -701,14 +669,12 @@ void CompositorInstance::createResources(bool forResizeOnly)
             
             if(width == 0)
             {
-                width = static_cast<size_t>(
-                                            static_cast<float>(mChain->getViewport()->getActualWidth()) * def->widthFactor);
+                width = static_cast<float>(mChain->getViewport()->getActualWidth()) * def->widthFactor;
                 width = width == 0 ? 1 : width;
             }
             if(height == 0)
             {
-                height = static_cast<size_t>(
-                                             static_cast<float>(mChain->getViewport()->getActualHeight()) * def->heightFactor);
+                height = static_cast<float>(mChain->getViewport()->getActualHeight()) * def->heightFactor;
                 height = height == 0 ? 1 : height;
             }
             
@@ -745,14 +711,13 @@ void CompositorInstance::createResources(bool forResizeOnly)
                                                                                  mrtLocalName, 
                                                                                  width, height, *p, fsaa, fsaaHint,  
                                                                                  hwGamma && !PixelUtil::isFloatingPoint(*p), 
-                                                                                 assignedTextures, this, def->scope);
+                                                                                 assignedTextures, this, def->scope, def->type);
                     }
                     else
                     {
-                        tex = TextureManager::getSingleton().createManual(
-                                                                          texname, 
-                                                                          ResourceGroupManager::INTERNAL_RESOURCE_GROUP_NAME, TEX_TYPE_2D, 
-                                                                          (uint)width, (uint)height, 0, *p, TU_RENDERTARGET, 0, 
+                        tex = TextureManager::getSingleton().createManual(texname,
+                                                                          RGN_INTERNAL, def->type,
+                                                                          width, height, 0, *p, TU_RENDERTARGET, 0,
                                                                           hwGamma && !PixelUtil::isFloatingPoint(*p), fsaa, fsaaHint ); 
                     }
                     
@@ -765,7 +730,7 @@ void CompositorInstance::createResources(bool forResizeOnly)
                     
                 }
                 
-                rendTarget = mrt;
+                setupRenderTarget(mrt, def->depthBufferId);
             }
             else
             {
@@ -776,71 +741,77 @@ void CompositorInstance::createResources(bool forResizeOnly)
                 // this is an auto generated name - so no spaces can't hart us.
                 std::replace( texName.begin(), texName.end(), ' ', '_' ); 
                 
+                hwGamma = hwGamma && !PixelUtil::isFloatingPoint(def->formatList[0]);
+
                 TexturePtr tex;
                 if (def->pooled)
                 {
                     // get / create pooled texture
                     tex = CompositorManager::getSingleton().getPooledTexture(texName, 
                                                                              def->name, width, height, def->formatList[0], fsaa, fsaaHint,
-                                                                             hwGamma && !PixelUtil::isFloatingPoint(def->formatList[0]), assignedTextures, 
-                                                                             this, def->scope);
+                                                                             hwGamma, assignedTextures,
+                                                                             this, def->scope, def->type);
                 }
                 else
                 {
                     tex = TextureManager::getSingleton().createManual(
-                                                                      texName, 
-                                                                      ResourceGroupManager::INTERNAL_RESOURCE_GROUP_NAME, TEX_TYPE_2D, 
-                                                                      (uint)width, (uint)height, 0, def->formatList[0], TU_RENDERTARGET, 0,
-                                                                      hwGamma && !PixelUtil::isFloatingPoint(def->formatList[0]), fsaa, fsaaHint); 
+                        texName, RGN_INTERNAL, def->type, width, height, 0, def->formatList[0],
+                        TU_RENDERTARGET, 0, hwGamma, fsaa, fsaaHint);
                 }
-                
-                rendTarget = tex->getBuffer()->getRenderTarget();
-                mLocalTextures[def->name] = tex;
-            }
-        }
-        
-        if(!PixelUtil::isDepth(rendTarget->suggestPixelFormat()))
-        {
-            //Set DepthBuffer pool for sharing
-            rendTarget->setDepthBufferPool( def->depthBufferId );
-        }
 
-        /// Set up viewport over entire texture
-        rendTarget->setAutoUpdated( false );
-        
-        // We may be sharing / reusing this texture, so test before adding viewport
-        if (rendTarget->getNumViewports() == 0)
-        {
-            Viewport* v;
-            Camera* camera = mChain->getViewport()->getCamera();
-            if (!camera)
-            {
-                v = rendTarget->addViewport( camera );
+                mLocalTextures[def->name] = tex;
+
+                for(size_t i = 0; i < tex->getNumFaces(); i++)
+                    setupRenderTarget(tex->getBuffer(i)->getRenderTarget(), def->depthBufferId);
             }
-            else
-            {
-                // Save last viewport and current aspect ratio
-                Viewport* oldViewport = camera->getViewport();
-                Real aspectRatio = camera->getAspectRatio();
-                
-                v = rendTarget->addViewport( camera );
-                
-                // Should restore aspect ratio, in case of auto aspect ratio
-                // enabled, it'll changed when add new viewport.
-                camera->setAspectRatio(aspectRatio);
-                // Should restore last viewport, i.e. never disturb user code
-                // which might based on that.
-                camera->_notifyViewport(oldViewport);
-            }
-            
-            v->setClearEveryFrame( false );
-            v->setOverlaysEnabled( false );
-            v->setBackgroundColour( ColourValue( 0, 0, 0, 0 ) );
         }
     }
-    
+
     _fireNotifyResourcesCreated(forResizeOnly);
 }
+
+void CompositorInstance::setupRenderTarget(RenderTarget* rendTarget, uint16 depthBufferId)
+{
+    if(rendTarget->getDepthBufferPool() != DepthBuffer::POOL_NO_DEPTH)
+    {
+        //Set DepthBuffer pool for sharing
+        rendTarget->setDepthBufferPool( depthBufferId );
+    }
+
+    /// Set up viewport over entire texture
+    rendTarget->setAutoUpdated( false );
+
+    // We may be sharing / reusing this texture, so test before adding viewport
+    if (rendTarget->getNumViewports() != 0)
+        return;
+
+    Viewport* v;
+    Camera* camera = mChain->getViewport()->getCamera();
+    if (!camera)
+    {
+        v = rendTarget->addViewport( camera );
+    }
+    else
+    {
+        // Save last viewport and current aspect ratio
+        Viewport* oldViewport = camera->getViewport();
+        Real aspectRatio = camera->getAspectRatio();
+        
+        v = rendTarget->addViewport( camera );
+
+        // Should restore aspect ratio, in case of auto aspect ratio
+        // enabled, it'll changed when add new viewport.
+        camera->setAspectRatio(aspectRatio);
+        // Should restore last viewport, i.e. never disturb user code
+        // which might based on that.
+        camera->_notifyViewport(oldViewport);
+    }
+    
+    v->setClearEveryFrame( false );
+    v->setOverlaysEnabled( false );
+    v->setBackgroundColour( ColourValue( 0, 0, 0, 0 ) );
+}
+
 //---------------------------------------------------------------------
 void CompositorInstance::deriveTextureRenderTargetOptions(
     const String& texname, bool *hwGammaWrite, uint *fsaa, String* fsaaHint)
@@ -850,10 +821,8 @@ void CompositorInstance::deriveTextureRenderTargetOptions(
     bool renderingScene = false;
 
     const CompositionTechnique::TargetPasses& passes = mTechnique->getTargetPasses();
-    CompositionTechnique::TargetPasses::const_iterator it;
-    for (it = passes.begin(); it != passes.end(); ++it)
+    for (auto *tp : passes)
     {
-        CompositionTargetPass* tp = *it;
         if (tp->getOutputName() == texname)
         {
             if (tp->getInputMode() == CompositionTargetPass::IM_PREVIOUS)
@@ -930,11 +899,8 @@ void CompositorInstance::freeResources(bool forResizeOnly, bool clearReserveText
     // required (saves some time & memory thrashing / fragmentation on resize)
 
     const CompositionTechnique::TextureDefinitions& tdefs = mTechnique->getTextureDefinitions();
-    CompositionTechnique::TextureDefinitions::const_iterator it = tdefs.begin();
-    for (; it != tdefs.end(); ++it)
+    for (auto *def : tdefs)
     {
-        CompositionTechnique::TextureDefinition *def = *it;
-
         if (!def->refCompName.empty()) 
         {
             //This is a reference, isn't created here
@@ -993,15 +959,12 @@ void CompositorInstance::freeResources(bool forResizeOnly, bool clearReserveText
         if (forResizeOnly)
         {
             // just remove the ones which would be affected by a resize
-            for (ReserveTextureMap::iterator i = mReserveTextures.begin();
-                i != mReserveTextures.end(); )
+            for (auto& t : mReserveTextures)
             {
-                if (i->first->width == 0 || i->first->height == 0)
+                if (t.first->width == 0 || t.first->height == 0)
                 {
-                    mReserveTextures.erase(i++);
+                    mReserveTextures.erase(t.first);
                 }
-                else
-                    ++i;
             }
         }
         else
@@ -1017,9 +980,9 @@ void CompositorInstance::freeResources(bool forResizeOnly, bool clearReserveText
     CompositorManager::getSingleton().freePooledTextures(true);
 }
 //---------------------------------------------------------------------
-RenderTarget* CompositorInstance::getRenderTarget(const String& name)
+RenderTarget* CompositorInstance::getRenderTarget(const String& name, int slice)
 {
-    return getTargetForTex(name);
+    return getTargetForTex(name, slice);
 }
 
 CompositionTechnique::TextureDefinition*
@@ -1031,14 +994,11 @@ CompositorInstance::resolveTexReference(const CompositionTechnique::TextureDefin
     CompositionTechnique::TextureDefinition* refTexDef = 0;
 
     //Try chain first
-    if(mChain)
+    if (CompositorInstance* refCompInst = mChain->getCompositor(texDef->refCompName))
     {
-        CompositorInstance* refCompInst = mChain->getCompositor(texDef->refCompName);
-        if(!refCompInst)
-            OGRE_EXCEPT(Exception::ERR_ITEM_NOT_FOUND, "Referencing non-existent compositor");
-
-        refTexDef = refCompInst->getCompositor()->getSupportedTechnique(
-            refCompInst->getScheme())->getTextureDefinition(texDef->refTexName);
+        refTexDef = refCompInst->getCompositor()
+                        ->getSupportedTechnique(refCompInst->getScheme())
+                        ->getTextureDefinition(texDef->refTexName);
     }
 
     if(!refTexDef)
@@ -1049,12 +1009,13 @@ CompositorInstance::resolveTexReference(const CompositionTechnique::TextureDefin
         {
             refTexDef = refComp->getSupportedTechnique()->getTextureDefinition(texDef->refTexName);
         }
+
+        if (refTexDef && refTexDef->scope != CompositionTechnique::TS_GLOBAL)
+            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
+                        "Referenced texture '" + texDef->refTexName + "' must have global scope");
     }
 
-    if(!refTexDef)
-    {
-        OGRE_EXCEPT(Exception::ERR_ITEM_NOT_FOUND, "Referencing non-existent compositor texture");
-    }
+    OgreAssert(refTexDef, "Referencing non-existent compositor texture");
 
     if (refTexDef->scope == CompositionTechnique::TS_LOCAL)
         OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
@@ -1064,12 +1025,12 @@ CompositorInstance::resolveTexReference(const CompositionTechnique::TextureDefin
 }
 
 //-----------------------------------------------------------------------
-RenderTarget *CompositorInstance::getTargetForTex(const String &name)
+RenderTarget *CompositorInstance::getTargetForTex(const String &name, int slice)
 {
     // try simple texture
     LocalTextureMap::iterator i = mLocalTextures.find(name);
     if(i != mLocalTextures.end())
-        return i->second->getBuffer()->getRenderTarget();
+        return i->second->getBuffer(slice)->getRenderTarget();
 
     // try MRTs
     LocalMRTMap::iterator mi = mLocalMRTs.find(name);
@@ -1088,7 +1049,6 @@ RenderTarget *CompositorInstance::getTargetForTex(const String &name)
             {
                 //Find the instance and check if it is before us
                 CompositorInstance* refCompInst = 0;
-                OgreAssert(mChain, "Undefined compositor chain");
                 bool beforeMe = true;
                 for (CompositorInstance* nextCompInst : mChain->getCompositorInstances())
                 {
@@ -1105,28 +1065,16 @@ RenderTarget *CompositorInstance::getTargetForTex(const String &name)
                     }
                 }
                 
-                if (refCompInst == 0 || !refCompInst->getEnabled()) 
-                {
-                    OGRE_EXCEPT(Exception::ERR_INVALID_STATE, "Referencing inactive compositor texture",
-                        "CompositorInstance::getTargetForTex");
-                }
-                if (!beforeMe)
-                {
-                    OGRE_EXCEPT(Exception::ERR_INVALID_STATE, "Referencing compositor that is later in the chain",
-                        "CompositorInstance::getTargetForTex");
-                }
-                return refCompInst->getRenderTarget(texDef->refTexName);
+                OgreAssert(refCompInst && refCompInst->getEnabled(), "Referencing inactive compositor texture");
+                OgreAssert(beforeMe, "Referencing compositor that is later in the chain");
+                return refCompInst->getRenderTarget(texDef->refTexName, slice);
             }
             case CompositionTechnique::TS_GLOBAL:
             {
                 //Chain and global case - the referenced compositor will know how to handle
                 const CompositorPtr& refComp = CompositorManager::getSingleton().getByName(texDef->refCompName);
-                if(!refComp)
-                {
-                    OGRE_EXCEPT(Exception::ERR_ITEM_NOT_FOUND, "Referencing non-existent compositor",
-                        "CompositorInstance::getTargetForTex");
-                }
-                return refComp->getRenderTarget(texDef->refTexName);
+                OgreAssert(refComp, "Referencing non-existent compositor");
+                return refComp->getRenderTarget(texDef->refTexName, slice);
             }
             case CompositionTechnique::TS_LOCAL:
                 break; // handled by resolveTexReference
@@ -1138,14 +1086,10 @@ RenderTarget *CompositorInstance::getTargetForTex(const String &name)
 
 }
 //-----------------------------------------------------------------------
-const String &CompositorInstance::getSourceForTex(const String &name, size_t mrtIndex)
+const TexturePtr &CompositorInstance::getSourceForTex(const String &name, size_t mrtIndex)
 {
     CompositionTechnique::TextureDefinition* texDef = mTechnique->getTextureDefinition(name);
-    if(texDef == 0)
-    {
-        OGRE_EXCEPT(Exception::ERR_ITEM_NOT_FOUND, "Referencing non-existent TextureDefinition",
-                    "CompositorInstance::getSourceForTex");
-    }
+    OgreAssert(texDef, "Referencing non-existent TextureDefinition");
     
     //Check if texture definition is reference
     if(!texDef->refCompName.empty())
@@ -1158,7 +1102,6 @@ const String &CompositorInstance::getSourceForTex(const String &name, size_t mrt
             {
                 //Find the instance and check if it is before us
                 CompositorInstance* refCompInst = 0;
-                OgreAssert(mChain, "Undefined compositor chain");
                 bool beforeMe = true;
                 for (CompositorInstance* nextCompInst : mChain->getCompositorInstances())
                 {
@@ -1174,29 +1117,17 @@ const String &CompositorInstance::getSourceForTex(const String &name, size_t mrt
                         beforeMe = false;
                     }
                 }
-                
-                if (refCompInst == 0 || !refCompInst->getEnabled()) 
-                {
-                    OGRE_EXCEPT(Exception::ERR_INVALID_STATE, "Referencing inactive compositor texture",
-                        "CompositorInstance::getSourceForTex");
-                }
-                if (!beforeMe)
-                {
-                    OGRE_EXCEPT(Exception::ERR_INVALID_STATE, "Referencing compositor that is later in the chain",
-                        "CompositorInstance::getSourceForTex");
-                }
-                return refCompInst->getTextureInstanceName(texDef->refTexName, mrtIndex);
+
+                OgreAssert(refCompInst && refCompInst->getEnabled(), "Referencing inactive compositor texture");
+                OgreAssert(beforeMe, "Referencing compositor that is later in the chain");
+                return refCompInst->getTextureInstance(texDef->refTexName, mrtIndex);
             }
             case CompositionTechnique::TS_GLOBAL:
             {
                 //Chain and global case - the referenced compositor will know how to handle
                 const CompositorPtr& refComp = CompositorManager::getSingleton().getByName(texDef->refCompName);
-                if(!refComp)
-                {
-                    OGRE_EXCEPT(Exception::ERR_ITEM_NOT_FOUND, "Referencing non-existent compositor",
-                        "CompositorInstance::getSourceForTex");
-                }
-                return refComp->getTextureInstanceName(texDef->refTexName, mrtIndex);
+                OgreAssert(refComp, "Referencing non-existent compositor");
+                return refComp->getTextureInstance(texDef->refTexName, mrtIndex);
             }
             case CompositionTechnique::TS_LOCAL:
                 break; // handled by resolveTexReference
@@ -1210,7 +1141,7 @@ const String &CompositorInstance::getSourceForTex(const String &name, size_t mrt
         LocalTextureMap::iterator i = mLocalTextures.find(name);
         if(i != mLocalTextures.end())
         {
-            return i->second->getName();
+            return i->second;
         }
     }
     else
@@ -1219,7 +1150,7 @@ const String &CompositorInstance::getSourceForTex(const String &name, size_t mrt
         LocalTextureMap::iterator i = mLocalTextures.find(getMRTTexLocalName(name, mrtIndex));
         if (i != mLocalTextures.end())
         {
-            return i->second->getName();
+            return i->second;
         }
     }
     
@@ -1250,30 +1181,26 @@ void CompositorInstance::removeListener(Listener *l)
 //-----------------------------------------------------------------------
 void CompositorInstance::_fireNotifyMaterialSetup(uint32 pass_id, MaterialPtr &mat)
 {
-    Listeners::iterator i, iend=mListeners.end();
-    for(i=mListeners.begin(); i!=iend; ++i)
-        (*i)->notifyMaterialSetup(pass_id, mat);
+    for(auto *l : mListeners)
+        l->notifyMaterialSetup(pass_id, mat);
 }
 //-----------------------------------------------------------------------
 void CompositorInstance::_fireNotifyMaterialRender(uint32 pass_id, MaterialPtr &mat)
 {
-    Listeners::iterator i, iend=mListeners.end();
-    for(i=mListeners.begin(); i!=iend; ++i)
-        (*i)->notifyMaterialRender(pass_id, mat);
+    for(auto *l : mListeners)
+        l->notifyMaterialRender(pass_id, mat);
 }
 //-----------------------------------------------------------------------
 void CompositorInstance::_fireNotifyResourcesCreated(bool forResizeOnly)
 {
-    Listeners::iterator i, iend=mListeners.end();
-    for(i=mListeners.begin(); i!=iend; ++i)
-        (*i)->notifyResourcesCreated(forResizeOnly);
+    for(auto *l : mListeners)
+        l->notifyResourcesCreated(forResizeOnly);
 }
 //-----------------------------------------------------------------------
 void CompositorInstance::_fireNotifyResourcesReleased(bool forResizeOnly)
 {
-    Listeners::iterator i, iend=mListeners.end();
-    for(i=mListeners.begin(); i!=iend; ++i)
-        (*i)->notifyResourcesReleased(forResizeOnly);
+    for(auto *l : mListeners)
+        l->notifyResourcesReleased(forResizeOnly);
 }
 //-----------------------------------------------------------------------
 void CompositorInstance::notifyCameraChanged(Camera* camera)
