@@ -27,33 +27,84 @@ THE SOFTWARE.
 */
 #include "OgreStableHeaders.h"
 #include "OgreGpuProgram.h"
+
+#include <memory>
 #include "OgreGpuProgramManager.h"
 #include "OgreRenderSystemCapabilities.h"
 
 namespace Ogre
 {
     //-----------------------------------------------------------------------------
-    GpuProgram::CmdType GpuProgram::msTypeCmd;
-    GpuProgram::CmdSyntax GpuProgram::msSyntaxCmd;
-    GpuProgram::CmdSkeletal GpuProgram::msSkeletalCmd;
-    GpuProgram::CmdMorph GpuProgram::msMorphCmd;
-    GpuProgram::CmdPose GpuProgram::msPoseCmd;
-    GpuProgram::CmdVTF GpuProgram::msVTFCmd;
-    GpuProgram::CmdManualNamedConstsFile GpuProgram::msManNamedConstsFileCmd;
-    GpuProgram::CmdAdjacency GpuProgram::msAdjacencyCmd;
-    GpuProgram::CmdComputeGroupDims GpuProgram::msComputeGroupDimsCmd;
-    
+    namespace {
+    /// Command object - see ParamCommand
+    class CmdType : public ParamCommand
+    {
+    public:
+        String doGet(const void* target) const override;
+        void doSet(void* target, const String& val) override;
+    };
+    class CmdSyntax : public ParamCommand
+    {
+    public:
+        String doGet(const void* target) const override;
+        void doSet(void* target, const String& val) override;
+    };
+    class CmdSkeletal : public ParamCommand
+    {
+    public:
+        String doGet(const void* target) const override;
+        void doSet(void* target, const String& val) override;
+    };
+    class CmdMorph : public ParamCommand
+    {
+    public:
+        String doGet(const void* target) const override;
+        void doSet(void* target, const String& val) override;
+    };
+    class CmdPose : public ParamCommand
+    {
+    public:
+        String doGet(const void* target) const override;
+        void doSet(void* target, const String& val) override;
+    };
+    class CmdVTF : public ParamCommand
+    {
+    public:
+        String doGet(const void* target) const override;
+        void doSet(void* target, const String& val) override;
+    };
+    class CmdManualNamedConstsFile : public ParamCommand
+    {
+    public:
+        String doGet(const void* target) const override;
+        void doSet(void* target, const String& val) override;
+    };
+    class CmdAdjacency : public ParamCommand
+    {
+    public:
+        String doGet(const void* target) const override;
+        void doSet(void* target, const String& val) override;
+    };
 
-    GpuLogicalBufferStructPtr GpuProgram::mBoolLogicalToPhysical;
+    using CmdInstancing = SimpleParamCommand<GpuProgram, bool, &GpuProgram::isInstancingIncluded, &GpuProgram::setInstancingIncluded>;
+    // Command object for setting / getting parameters
+    static CmdType msTypeCmd;
+    static CmdSyntax msSyntaxCmd;
+    static CmdInstancing msInstancingCmd;
+    static CmdSkeletal msSkeletalCmd;
+    static CmdMorph msMorphCmd;
+    static CmdPose msPoseCmd;
+    static CmdVTF msVTFCmd;
+    static CmdManualNamedConstsFile msManNamedConstsFileCmd;
+    static CmdAdjacency msAdjacencyCmd;
+    }
 
     //-----------------------------------------------------------------------------
-    GpuProgram::GpuProgram(ResourceManager* creator, const String& name, ResourceHandle handle,
-        const String& group, bool isManual, ManualResourceLoader* loader) 
-        :Resource(creator, name, handle, group, isManual, loader),
-        mType(GPT_VERTEX_PROGRAM), mLoadFromFile(true), mSkeletalAnimation(false),
-        mMorphAnimation(false), mPoseAnimation(0),
-        mVertexTextureFetch(false), mNeedsAdjacencyInfo(false),
-        mCompileError(false), mLoadedManualNamedConstants(false)
+    GpuProgram::GpuProgram(ResourceManager* creator, const String& name, ResourceHandle handle, const String& group,
+                           bool isManual, ManualResourceLoader* loader)
+        : Resource(creator, name, handle, group, isManual, loader), mType(GPT_VERTEX_PROGRAM), mLoadFromFile(true),
+          mInstancing(false), mSkeletalAnimation(false), mMorphAnimation(false), mVertexTextureFetch(false),
+          mNeedsAdjacencyInfo(false), mCompileError(false), mLoadedManualNamedConstants(false), mPoseAnimation(0)
     {
         createParameterMappingStructures();
     }
@@ -70,6 +121,8 @@ namespace Ogre
     //-----------------------------------------------------------------------------
     void GpuProgram::setSourceFile(const String& filename)
     {
+        OgreAssert(!filename.empty(), "invalid filename");
+
         mFilename = filename;
         mSource.clear();
         mLoadFromFile = true;
@@ -93,73 +146,90 @@ namespace Ogre
 
     size_t GpuProgram::calculateSize(void) const
     {
-        size_t memSize = 0;
-        memSize += sizeof(bool) * 7;
+        size_t memSize = sizeof(*this);
         memSize += mManualNamedConstantsFile.size() * sizeof(char);
         memSize += mFilename.size() * sizeof(char);
         memSize += mSource.size() * sizeof(char);
         memSize += mSyntaxCode.size() * sizeof(char);
-        memSize += sizeof(GpuProgramType);
-        memSize += sizeof(ushort);
 
         size_t paramsSize = 0;
         if(mDefaultParams)
             paramsSize += mDefaultParams->calculateSize();
-        if(mFloatLogicalToPhysical)
-            paramsSize += mFloatLogicalToPhysical->bufferSize;
-        if(mDoubleLogicalToPhysical)
-            paramsSize += mDoubleLogicalToPhysical->bufferSize;
-        if(mIntLogicalToPhysical)
-            paramsSize += mIntLogicalToPhysical->bufferSize;
         if(mConstantDefs)
             paramsSize += mConstantDefs->calculateSize();
 
         return memSize + paramsSize;
     }
     //-----------------------------------------------------------------------------
+    void GpuProgram::prepareImpl()
+    {
+        if (!mLoadFromFile)
+            return;
+
+        mSource = ResourceGroupManager::getSingleton().openResource(mFilename, mGroup, this)->getAsString();
+    }
+
+    void GpuProgram::safePrepare()
+    {
+        try
+        {
+            prepare();
+        }
+        catch (const RuntimeAssertionException&)
+        {
+            throw;
+        }
+        catch (const Exception& e)
+        {
+            // will already have been logged
+            LogManager::getSingleton().stream(LML_CRITICAL)
+                << "Program '" << mName << "' is not supported: " << e.getDescription();
+
+            mCompileError = true;
+        }
+    }
+
     void GpuProgram::loadImpl(void)
     {
-        if (mLoadFromFile)
-        {
-            // find & load source code
-            DataStreamPtr stream = 
-                ResourceGroupManager::getSingleton().openResource(
-                    mFilename, mGroup, this);
-            mSource = stream->getAsString();
-        }
+        if(mCompileError)
+            return;
 
         // Call polymorphic load
         try 
         {
             loadFromSource();
-
-            if (mDefaultParams)
-            {
-                // Keep a reference to old ones to copy
-                GpuProgramParametersSharedPtr savedParams = mDefaultParams;
-                // reset params to stop them being referenced in the next create
-                mDefaultParams.reset();
-
-                // Create new params
-                mDefaultParams = createParameters();
-
-                // Copy old (matching) values across
-                // Don't use copyConstantsFrom since program may be different
-                mDefaultParams->copyMatchingNamedConstantsFrom(*savedParams.get());
-
-            }
         }
-        catch (const Exception&)
+        catch (const RuntimeAssertionException&)
+        {
+            throw;
+        }
+        catch (const Exception& e)
         {
             // will already have been logged
-            LogManager::getSingleton().stream()
-                << "Gpu program " << mName << " encountered an error "
-                << "during loading and is thus not supported.";
+            LogManager::getSingleton().stream(LML_CRITICAL)
+                << "Program '" << mName << "' is not supported: " << e.getDescription();
 
             mCompileError = true;
         }
-
     }
+    void GpuProgram::postLoadImpl()
+    {
+        if (!mDefaultParams || mCompileError)
+            return;
+
+        // Keep a reference to old ones to copy
+        GpuProgramParametersSharedPtr savedParams = mDefaultParams;
+        // reset params to stop them being referenced in the next create
+        mDefaultParams.reset();
+
+        // Create new params
+        mDefaultParams = createParameters();
+
+        // Copy old (matching) values across
+        // Don't use copyConstantsFrom since program may be different
+        mDefaultParams->copyMatchingNamedConstantsFrom(*savedParams.get());
+    }
+
     //-----------------------------------------------------------------------------
     bool GpuProgram::isRequiredCapabilitiesSupported(void) const
     {
@@ -167,9 +237,7 @@ namespace Ogre
             Root::getSingleton().getRenderSystem()->getCapabilities();
 
         // Basic support check
-        if ((getType() == GPT_VERTEX_PROGRAM && !caps->hasCapability(RSC_VERTEX_PROGRAM)) ||
-            (getType() == GPT_GEOMETRY_PROGRAM && !caps->hasCapability(RSC_GEOMETRY_PROGRAM)) ||
-            (getType() == GPT_FRAGMENT_PROGRAM && !caps->hasCapability(RSC_FRAGMENT_PROGRAM)) ||
+        if ((getType() == GPT_GEOMETRY_PROGRAM && !caps->hasCapability(RSC_GEOMETRY_PROGRAM)) ||
             (getType() == GPT_DOMAIN_PROGRAM && !caps->hasCapability(RSC_TESSELLATION_DOMAIN_PROGRAM)) ||
             (getType() == GPT_HULL_PROGRAM && !caps->hasCapability(RSC_TESSELLATION_HULL_PROGRAM)) ||
             (getType() == GPT_COMPUTE_PROGRAM && !caps->hasCapability(RSC_COMPUTE_PROGRAM)))
@@ -177,13 +245,6 @@ namespace Ogre
             return false;
         }
 
-        // If skeletal animation is being done, we need support for UBYTE4
-        if (isSkeletalAnimationIncluded() && 
-            !caps->hasCapability(RSC_VERTEX_FORMAT_UBYTE4))
-        {
-            return false;
-        }
-
         // Vertex texture fetch required?
         if (isVertexTextureFetchRequired() && 
             !caps->hasCapability(RSC_VERTEX_TEXTURE_FETCH))
@@ -202,24 +263,22 @@ namespace Ogre
         return GpuProgramManager::getSingleton().isSyntaxSupported(mSyntaxCode);
     }
     //---------------------------------------------------------------------
-    void GpuProgram::createParameterMappingStructures(bool recreateIfExists) const
+    void GpuProgram::createParameterMappingStructures(bool recreateIfExists)
     {
         createLogicalParameterMappingStructures(recreateIfExists);
         createNamedParameterMappingStructures(recreateIfExists);
     }
     //---------------------------------------------------------------------
-    void GpuProgram::createLogicalParameterMappingStructures(bool recreateIfExists) const
+    void GpuProgram::createLogicalParameterMappingStructures(bool recreateIfExists)
     {
-        if (recreateIfExists || !mFloatLogicalToPhysical)
-            mFloatLogicalToPhysical = GpuLogicalBufferStructPtr(OGRE_NEW GpuLogicalBufferStruct());
-        if (recreateIfExists || !mIntLogicalToPhysical)
-            mIntLogicalToPhysical = GpuLogicalBufferStructPtr(OGRE_NEW GpuLogicalBufferStruct());
+        if (recreateIfExists || !mLogicalToPhysical)
+            mLogicalToPhysical = std::make_shared<GpuLogicalBufferStruct>();
     }
     //---------------------------------------------------------------------
-    void GpuProgram::createNamedParameterMappingStructures(bool recreateIfExists) const
+    void GpuProgram::createNamedParameterMappingStructures(bool recreateIfExists)
     {
         if (recreateIfExists || !mConstantDefs)
-            mConstantDefs = GpuNamedConstantsPtr(OGRE_NEW GpuNamedConstants());
+            mConstantDefs = std::make_shared<GpuNamedConstants>();
     }
     //---------------------------------------------------------------------
     void GpuProgram::setManualNamedConstantsFile(const String& paramDefFile)
@@ -233,10 +292,8 @@ namespace Ogre
         createParameterMappingStructures();
         *mConstantDefs.get() = namedConstants;
 
-        mFloatLogicalToPhysical->bufferSize = mConstantDefs->floatBufferSize;
-        mIntLogicalToPhysical->bufferSize = mConstantDefs->intBufferSize;
-        mFloatLogicalToPhysical->map.clear();
-        mIntLogicalToPhysical->map.clear();
+        mLogicalToPhysical->bufferSize = mConstantDefs->bufferSize;
+        mLogicalToPhysical->map.clear();
         // need to set up logical mappings too for some rendersystems
         for (GpuConstantDefinitionMap::const_iterator i = mConstantDefs->map.begin();
             i != mConstantDefs->map.end(); ++i)
@@ -246,16 +303,11 @@ namespace Ogre
             // only consider non-array entries
             if (name.find('[') == String::npos)
             {
-                GpuLogicalIndexUseMap::value_type val(def.logicalIndex, 
-                    GpuLogicalIndexUse(def.physicalIndex, def.arraySize * def.elementSize, def.variability));
-                if (def.isFloat())
-                {
-                    mFloatLogicalToPhysical->map.emplace(val);
-                }
-                else
-                {
-                    mIntLogicalToPhysical->map.emplace(val);
-                }
+                GpuLogicalIndexUseMap::value_type val(
+                    def.logicalIndex,
+                    GpuLogicalIndexUse(def.physicalIndex, def.arraySize * def.elementSize, def.variability,
+                                       GpuConstantDefinition::getBaseType(def.constType)));
+                mLogicalToPhysical->map.emplace(val);
             }
         }
 
@@ -297,8 +349,7 @@ namespace Ogre
             ret->_setNamedConstants(mConstantDefs);
         }
         // link shared logical / physical map for low-level use
-        ret->_setLogicalIndexes(mFloatLogicalToPhysical, mDoubleLogicalToPhysical,
-                                mIntLogicalToPhysical);
+        ret->_setLogicalIndexes(mLogicalToPhysical);
 
         // Copy in default parameters if present
         if (mDefaultParams)
@@ -307,7 +358,7 @@ namespace Ogre
         return ret;
     }
     //-----------------------------------------------------------------------------
-    GpuProgramParametersSharedPtr GpuProgram::getDefaultParameters(void)
+    const GpuProgramParametersPtr& GpuProgram::getDefaultParameters(void)
     {
         if (!mDefaultParams)
         {
@@ -348,6 +399,7 @@ namespace Ogre
                          PT_STRING), &msTypeCmd);
         dict->addParameter(
             ParameterDef("syntax", "Syntax code, e.g. vs_1_1", PT_STRING), &msSyntaxCmd);
+        dict->addParameter("includes_instancing", &msInstancingCmd);
         dict->addParameter(
             ParameterDef("includes_skeletal_animation", 
                          "Whether this vertex program includes skeletal animation", PT_BOOL), 
@@ -372,11 +424,6 @@ namespace Ogre
             ParameterDef("uses_adjacency_information",
                          "Whether this geometry program requires adjacency information from the input primitives.", PT_BOOL),
             &msAdjacencyCmd);
-        dict->addParameter(
-            ParameterDef("compute_group_dimensions",
-                         "The number of process groups created by this compute program.", PT_VECTOR3),
-            &msComputeGroupDimsCmd);
-            
     }
 
     //-----------------------------------------------------------------------
@@ -388,35 +435,12 @@ namespace Ogre
     }
     //-----------------------------------------------------------------------
     //-----------------------------------------------------------------------
-    String GpuProgram::CmdType::doGet(const void* target) const
+    String CmdType::doGet(const void* target) const
     {
         const GpuProgram* t = static_cast<const GpuProgram*>(target);
-        if (t->getType() == GPT_VERTEX_PROGRAM)
-        {
-            return "vertex_program";
-        }
-        else if (t->getType() == GPT_GEOMETRY_PROGRAM)
-        {
-            return "geometry_program";
-        }
-        else if (t->getType() == GPT_DOMAIN_PROGRAM)
-        {
-            return "domain_program";
-        }
-        else if (t->getType() == GPT_HULL_PROGRAM)
-        {
-            return "hull_program";
-        }
-        else if (t->getType() == GPT_COMPUTE_PROGRAM)
-        {
-            return "compute_program";
-        }
-        else
-        {
-            return "fragment_program";
-        }
+        return GpuProgram::getProgramTypeName(t->getType()) + "_program";
     }
-    void GpuProgram::CmdType::doSet(void* target, const String& val)
+    void CmdType::doSet(void* target, const String& val)
     {
         GpuProgram* t = static_cast<GpuProgram*>(target);
         if (val == "vertex_program")
@@ -445,94 +469,85 @@ namespace Ogre
         }
     }
     //-----------------------------------------------------------------------
-    String GpuProgram::CmdSyntax::doGet(const void* target) const
+    String CmdSyntax::doGet(const void* target) const
     {
         const GpuProgram* t = static_cast<const GpuProgram*>(target);
         return t->getSyntaxCode();
     }
-    void GpuProgram::CmdSyntax::doSet(void* target, const String& val)
+    void CmdSyntax::doSet(void* target, const String& val)
     {
         GpuProgram* t = static_cast<GpuProgram*>(target);
         t->setSyntaxCode(val);
     }
     //-----------------------------------------------------------------------
-    String GpuProgram::CmdSkeletal::doGet(const void* target) const
+    String CmdSkeletal::doGet(const void* target) const
     {
         const GpuProgram* t = static_cast<const GpuProgram*>(target);
         return StringConverter::toString(t->isSkeletalAnimationIncluded());
     }
-    void GpuProgram::CmdSkeletal::doSet(void* target, const String& val)
+    void CmdSkeletal::doSet(void* target, const String& val)
     {
         GpuProgram* t = static_cast<GpuProgram*>(target);
         t->setSkeletalAnimationIncluded(StringConverter::parseBool(val));
     }
     //-----------------------------------------------------------------------
-    String GpuProgram::CmdMorph::doGet(const void* target) const
+    String CmdMorph::doGet(const void* target) const
     {
         const GpuProgram* t = static_cast<const GpuProgram*>(target);
         return StringConverter::toString(t->isMorphAnimationIncluded());
     }
-    void GpuProgram::CmdMorph::doSet(void* target, const String& val)
+    void CmdMorph::doSet(void* target, const String& val)
     {
         GpuProgram* t = static_cast<GpuProgram*>(target);
         t->setMorphAnimationIncluded(StringConverter::parseBool(val));
     }
     //-----------------------------------------------------------------------
-    String GpuProgram::CmdPose::doGet(const void* target) const
+    String CmdPose::doGet(const void* target) const
     {
         const GpuProgram* t = static_cast<const GpuProgram*>(target);
         return StringConverter::toString(t->getNumberOfPosesIncluded());
     }
-    void GpuProgram::CmdPose::doSet(void* target, const String& val)
+    void CmdPose::doSet(void* target, const String& val)
     {
         GpuProgram* t = static_cast<GpuProgram*>(target);
         t->setPoseAnimationIncluded((ushort)StringConverter::parseUnsignedInt(val));
     }
     //-----------------------------------------------------------------------
-    String GpuProgram::CmdVTF::doGet(const void* target) const
+    String CmdVTF::doGet(const void* target) const
     {
         const GpuProgram* t = static_cast<const GpuProgram*>(target);
         return StringConverter::toString(t->isVertexTextureFetchRequired());
     }
-    void GpuProgram::CmdVTF::doSet(void* target, const String& val)
+    void CmdVTF::doSet(void* target, const String& val)
     {
         GpuProgram* t = static_cast<GpuProgram*>(target);
         t->setVertexTextureFetchRequired(StringConverter::parseBool(val));
     }
     //-----------------------------------------------------------------------
-    String GpuProgram::CmdManualNamedConstsFile::doGet(const void* target) const
+    String CmdManualNamedConstsFile::doGet(const void* target) const
     {
         const GpuProgram* t = static_cast<const GpuProgram*>(target);
         return t->getManualNamedConstantsFile();
     }
-    void GpuProgram::CmdManualNamedConstsFile::doSet(void* target, const String& val)
+    void CmdManualNamedConstsFile::doSet(void* target, const String& val)
     {
         GpuProgram* t = static_cast<GpuProgram*>(target);
         t->setManualNamedConstantsFile(val);
     }
     //-----------------------------------------------------------------------
-    String GpuProgram::CmdAdjacency::doGet(const void* target) const
+    String CmdAdjacency::doGet(const void* target) const
     {
         const GpuProgram* t = static_cast<const GpuProgram*>(target);
         return StringConverter::toString(t->isAdjacencyInfoRequired());
     }
-    void GpuProgram::CmdAdjacency::doSet(void* target, const String& val)
+    void CmdAdjacency::doSet(void* target, const String& val)
     {
         LogManager::getSingleton().logWarning("'uses_adjacency_information' is deprecated. "
         "Set the respective RenderOperation::OpertionType instead.");
         GpuProgram* t = static_cast<GpuProgram*>(target);
-        t->mNeedsAdjacencyInfo = StringConverter::parseBool(val);
-    }
-    //-----------------------------------------------------------------------
-    String GpuProgram::CmdComputeGroupDims::doGet(const void* target) const
-    {
-        const GpuProgram* t = static_cast<const GpuProgram*>(target);
-        return StringConverter::toString(t->getComputeGroupDimensions());
-    }
-    void GpuProgram::CmdComputeGroupDims::doSet(void* target, const String& val)
-    {
-        GpuProgram* t = static_cast<GpuProgram*>(target);
-        t->setComputeGroupDimensions(StringConverter::parseVector3(val));
+        OGRE_IGNORE_DEPRECATED_BEGIN
+        t->setAdjacencyInfoRequired(StringConverter::parseBool(val));
+        OGRE_IGNORE_DEPRECATED_END
     }
 }
 
