@@ -201,17 +201,13 @@ namespace Ogre
     {
         Material::Techniques::const_iterator t;
         for(t = material->getTechniques().begin(); t != material->getTechniques().end(); ++t)
+        for (auto *technique : material->getTechniques())
         {
-            Technique *technique = *t;
-            Technique::Passes::const_iterator i;
-            for(i = technique->getPasses().begin(); i != technique->getPasses().end(); ++i)
+            for (auto *pass : technique->getPasses())
             {
-                Pass *pass = *i;
                 Pass::TextureUnitStates::const_iterator it;
-                for(it = pass->getTextureUnitStates().begin(); it != pass->getTextureUnitStates().end(); ++it)
+                for(auto *texUnit : pass->getTextureUnitStates())
                 {
-                    TextureUnitState *texUnit = *it;
-
                     if( texUnit->getName() == "InstancingVTF" )
                     {
                         texUnit->setTextureName( mMatrixTexture->getName(), textureType );
@@ -223,7 +219,7 @@ namespace Ogre
             if( technique->getShadowCasterMaterial() )
             {
                 MaterialPtr matCaster = technique->getShadowCasterMaterial();
-                setupMaterialToUseVTF( textureType, matCaster );
+                setupMaterialToUseVTF(textureType, matCaster );
             }
         }
     }
@@ -426,11 +422,6 @@ namespace Ogre
         *xform = Matrix4::IDENTITY;
     }
     //-----------------------------------------------------------------------
-    unsigned short BaseInstanceBatchVTF::getNumWorldTransforms(void) const
-    {
-        return 1;
-    }
-    //-----------------------------------------------------------------------
     void BaseInstanceBatchVTF::_updateRenderQueue(RenderQueue* queue)
     {
         InstanceBatch::_updateRenderQueue( queue );
