@@ -1,65 +1,69 @@
 /*
 -----------------------------------------------------------------------------
-This source file is part of OGRE 
-	(Object-oriented Graphics Rendering Engine)
+This source file is part of OGRE
+(Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2006 Torus Knot Software Ltd
-Also see acknowledgements in Readme.html
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
-This program is free software; you can redistribute it and/or modify it under 
-the terms of the GNU Lesser General Public License as published by the Free Software 
-Foundation; either version 2 of the License, or (at your option) any later 
-version.
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
 
-This program is distributed in the hope that it will be useful, but WITHOUT 
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
-FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
 
-You should have received a copy of the GNU Lesser General Public License along with 
-this program; if not, write to the Free Software Foundation, Inc., 59 Temple 
-Place - Suite 330, Boston, MA 02111-1307, USA, or go to 
-http://www.gnu.org/copyleft/lesser.txt.
-
-You may alternatively use this source under the terms of a specific version of
-the OGRE Unrestricted License provided you have obtained such a license from
-Torus Knot Software Ltd.
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+THE SOFTWARE.
 -----------------------------------------------------------------------------
 */
 #include "OgreStableHeaders.h"
 
 #include "OgreParticleEmitter.h"
 #include "OgreParticleEmitterFactory.h"
+#include "OgreParticleEmitterCommands.h"
 
 namespace Ogre
 {
-	// Define static members
-    EmitterCommands::CmdAngle ParticleEmitter::msAngleCmd;
-    EmitterCommands::CmdColour ParticleEmitter::msColourCmd;
-    EmitterCommands::CmdColourRangeStart ParticleEmitter::msColourRangeStartCmd;
-    EmitterCommands::CmdColourRangeEnd ParticleEmitter::msColourRangeEndCmd;
-    EmitterCommands::CmdDirection ParticleEmitter::msDirectionCmd;
-    EmitterCommands::CmdEmissionRate ParticleEmitter::msEmissionRateCmd;
-    EmitterCommands::CmdMaxTTL ParticleEmitter::msMaxTTLCmd;
-    EmitterCommands::CmdMaxVelocity ParticleEmitter::msMaxVelocityCmd;
-    EmitterCommands::CmdMinTTL ParticleEmitter::msMinTTLCmd;
-    EmitterCommands::CmdMinVelocity ParticleEmitter::msMinVelocityCmd;
-    EmitterCommands::CmdPosition ParticleEmitter::msPositionCmd;
-    EmitterCommands::CmdTTL ParticleEmitter::msTTLCmd;
-    EmitterCommands::CmdVelocity ParticleEmitter::msVelocityCmd;
-    EmitterCommands::CmdDuration ParticleEmitter::msDurationCmd;
-    EmitterCommands::CmdMinDuration ParticleEmitter::msMinDurationCmd;
-    EmitterCommands::CmdMaxDuration ParticleEmitter::msMaxDurationCmd;
-    EmitterCommands::CmdRepeatDelay ParticleEmitter::msRepeatDelayCmd;
-    EmitterCommands::CmdMinRepeatDelay ParticleEmitter::msMinRepeatDelayCmd;
-    EmitterCommands::CmdMaxRepeatDelay ParticleEmitter::msMaxRepeatDelayCmd;
-    EmitterCommands::CmdName ParticleEmitter::msNameCmd;
-    EmitterCommands::CmdEmittedEmitter ParticleEmitter::msEmittedEmitterCmd;
+    // Command object for setting / getting parameters
+    static EmitterCommands::CmdAngle msAngleCmd;
+    static EmitterCommands::CmdColour msColourCmd;
+    static EmitterCommands::CmdColourRangeStart msColourRangeStartCmd;
+    static EmitterCommands::CmdColourRangeEnd msColourRangeEndCmd;
+    static EmitterCommands::CmdDirection msDirectionCmd;
+    static EmitterCommands::CmdUp msUpCmd;
+    static EmitterCommands::CmdDirPositionRef msDirPositionRefCmd;
+    static EmitterCommands::CmdEmissionRate msEmissionRateCmd;
+    static EmitterCommands::CmdMaxTTL msMaxTTLCmd;
+    static EmitterCommands::CmdMaxVelocity msMaxVelocityCmd;
+    static EmitterCommands::CmdMinTTL msMinTTLCmd;
+    static EmitterCommands::CmdMinVelocity msMinVelocityCmd;
+    static EmitterCommands::CmdPosition msPositionCmd;
+    static EmitterCommands::CmdTTL msTTLCmd;
+    static EmitterCommands::CmdVelocity msVelocityCmd;
+    static EmitterCommands::CmdDuration msDurationCmd;
+    static EmitterCommands::CmdMinDuration msMinDurationCmd;
+    static EmitterCommands::CmdMaxDuration msMaxDurationCmd;
+    static EmitterCommands::CmdRepeatDelay msRepeatDelayCmd;
+    static EmitterCommands::CmdMinRepeatDelay msMinRepeatDelayCmd;
+    static EmitterCommands::CmdMaxRepeatDelay msMaxRepeatDelayCmd;
+    static EmitterCommands::CmdName msNameCmd;
+    static EmitterCommands::CmdEmittedEmitter msEmittedEmitterCmd;
 
 
     //-----------------------------------------------------------------------
     ParticleEmitter::ParticleEmitter(ParticleSystem* psys)
       : mParent(psys),
+        mUseDirPositionRef(false),
+        mDirPositionRef(Vector3::ZERO),
         mStartTime(0),
         mDurationMin(0),
         mDurationMax(0),
@@ -79,9 +83,9 @@ namespace Ogre
         mColourRangeStart = mColourRangeEnd = ColourValue::White;
         mEnabled = true;
         mRemainder = 0;
-		mName = StringUtil::BLANK;
-		mEmittedEmitter = StringUtil::BLANK;
-		mEmitted = false;
+        mName = BLANKSTRING;
+        mEmittedEmitter = BLANKSTRING;
+        mEmitted = false;
     }
     //-----------------------------------------------------------------------
     ParticleEmitter::~ParticleEmitter() 
@@ -98,11 +102,11 @@ namespace Ogre
         return mPosition; 
     }
     //-----------------------------------------------------------------------
-    void ParticleEmitter::setDirection(const Vector3& direction) 
+    void ParticleEmitter::setDirection(const Vector3& inDirection) 
     { 
-        mDirection = direction; 
+        mDirection = inDirection; 
         mDirection.normalise();
-        // Generate an up vector (any will do)
+        // Generate a default up vector.
         mUp = mDirection.perpendicular();
         mUp.normalise();
     }
@@ -112,6 +116,33 @@ namespace Ogre
         return mDirection; 
     }
     //-----------------------------------------------------------------------
+    void ParticleEmitter::setUp(const Vector3& inUp) 
+    {
+        mUp = inUp; 
+        mUp.normalise();
+    }
+    //-----------------------------------------------------------------------
+    const Vector3& ParticleEmitter::getUp(void) const
+    { 
+        return mUp; 
+    }
+    //-----------------------------------------------------------------------
+    void ParticleEmitter::setDirPositionReference( const Vector3& nposition, bool enable )
+    { 
+    mUseDirPositionRef  = enable;
+        mDirPositionRef     = nposition;
+    }
+    //-----------------------------------------------------------------------
+    const Vector3& ParticleEmitter::getDirPositionReference() const
+    {
+        return mDirPositionRef;
+    }
+    //-----------------------------------------------------------------------
+    bool ParticleEmitter::getDirPositionReferenceEnabled() const
+    {
+        return mUseDirPositionRef;
+    }
+    //-----------------------------------------------------------------------
     void ParticleEmitter::setAngle(const Radian& angle)
     {
         // Store as radians for efficiency
@@ -125,11 +156,13 @@ namespace Ogre
     //-----------------------------------------------------------------------
     void ParticleEmitter::setParticleVelocity(Real speed)
     {
+        assert(std::isfinite(speed));
         mMinSpeed = mMaxSpeed = speed;
     }
     //-----------------------------------------------------------------------
     void ParticleEmitter::setParticleVelocity(Real min, Real max)
     {
+        assert(std::isfinite(min) && std::isfinite(max));
         mMinSpeed = min;
         mMaxSpeed = max;
     }
@@ -146,18 +179,21 @@ namespace Ogre
     //-----------------------------------------------------------------------
     void ParticleEmitter::setTimeToLive(Real ttl)
     {
+        assert (ttl >= 0 && "Time to live can not be negative");
         mMinTTL = mMaxTTL = ttl;
     }
     //-----------------------------------------------------------------------
     void ParticleEmitter::setTimeToLive(Real minTtl, Real maxTtl)
     {
+        assert (minTtl >= 0 && "Time to live can not be negative");
+        assert (maxTtl >= 0 && "Time to live can not be negative");
         mMinTTL = minTtl;
         mMaxTTL = maxTtl;
     }
     //-----------------------------------------------------------------------
-    void ParticleEmitter::setColour(const ColourValue& colour)
+    void ParticleEmitter::setColour(const ColourValue& inColour)
     {
-        mColourRangeStart = mColourRangeEnd = colour;
+        mColourRangeStart = mColourRangeEnd = inColour;
     }
     //-----------------------------------------------------------------------
     void ParticleEmitter::setColour(const ColourValue& colourStart, const ColourValue& colourEnd)
@@ -165,56 +201,84 @@ namespace Ogre
         mColourRangeStart = colourStart;
         mColourRangeEnd = colourEnd;
     }
-	//-----------------------------------------------------------------------
+    //-----------------------------------------------------------------------
     const String& ParticleEmitter::getName(void) const
     {
         return mName;
     }
-	//-----------------------------------------------------------------------
+    //-----------------------------------------------------------------------
     void ParticleEmitter::setName(const String& newName)
     {
-		mName = newName;
+        mName = newName;
     }
-	//-----------------------------------------------------------------------
+    //-----------------------------------------------------------------------
     const String& ParticleEmitter::getEmittedEmitter(void) const
     {
         return mEmittedEmitter;
     }
-	//-----------------------------------------------------------------------
+    //-----------------------------------------------------------------------
     void ParticleEmitter::setEmittedEmitter(const String& emittedEmitter)
     {
         mEmittedEmitter = emittedEmitter;
     }
-	//-----------------------------------------------------------------------
-	bool ParticleEmitter::isEmitted(void) const
+    //-----------------------------------------------------------------------
+    bool ParticleEmitter::isEmitted(void) const
     {
-		return mEmitted;
+        return mEmitted;
     }
-	//-----------------------------------------------------------------------
-	void ParticleEmitter::setEmitted(bool emitted)
+    //-----------------------------------------------------------------------
+    void ParticleEmitter::setEmitted(bool emitted)
     {
         mEmitted = emitted;
     }
     //-----------------------------------------------------------------------
-    void ParticleEmitter::genEmissionDirection(Vector3& destVector)
+    static float sampleSphereUniform(const float& maxAngle)
     {
-        if (mAngle != Radian(0))
-        {
-            // Randomise angle
-            Radian angle = Math::UnitRandom() * mAngle;
+        float cosMax = -std::cos(maxAngle) + 1; // for maxAngle = pi, cosMax = 2
+        // see https://corysimon.github.io/articles/uniformdistn-on-sphere/
+        return std::acos(1 - cosMax * Math::UnitRandom());
+    }
 
-            // Randomise direction
-            destVector = mDirection.randomDeviant(angle, mUp);
+    void ParticleEmitter::genEmissionDirection( const Vector3 &particlePos, Vector3& destVector )
+    {
+        if( mUseDirPositionRef )
+        {
+            Vector3 particleDir = particlePos - mDirPositionRef;
+            particleDir.normalise();
+
+            if (mAngle != Radian(0))
+            {
+                // Randomise angle
+                Radian angle(sampleSphereUniform(mAngle.valueRadians()));
+
+                // Randomise direction
+                destVector = particleDir.randomDeviant( angle );
+            }
+            else
+            {
+                // Constant angle
+                destVector = particleDir;
+            }
         }
         else
         {
-            // Constant angle
-            destVector = mDirection;
+            if (mAngle != Radian(0))
+            {
+                // Randomise angle
+                Radian angle(sampleSphereUniform(mAngle.valueRadians()));
+
+                // Randomise direction
+                destVector = mDirection.randomDeviant(angle, mUp);
+            }
+            else
+            {
+                // Constant angle
+                destVector = mDirection;
+            }
         }
 
         // Don't normalise, we can assume that it will still be a unit vector since
         // both direction and 'up' are.
-
     }
     //-----------------------------------------------------------------------
     void ParticleEmitter::genEmissionVelocity(Vector3& destVector)
@@ -246,13 +310,17 @@ namespace Ogre
     //-----------------------------------------------------------------------
     unsigned short ParticleEmitter::genConstantEmissionCount(Real timeElapsed)
     {
-        unsigned short intRequest;
-        
         if (mEnabled)
         {
+            if(mDurationMax < 0)
+            {
+                // single-shot burst
+                setEnabled(false);
+                return mEmissionRate;
+            }
             // Keep fractions, otherwise a high frame rate will result in zero emissions!
             mRemainder += mEmissionRate * timeElapsed;
-            intRequest = (unsigned short)mRemainder;
+            unsigned short intRequest = (unsigned short)mRemainder;
             mRemainder -= intRequest;
 
             // Check duration
@@ -293,20 +361,17 @@ namespace Ogre
 
     }
     //-----------------------------------------------------------------------
-    void ParticleEmitter::genEmissionColour(ColourValue& destColour)
+    void ParticleEmitter::genEmissionColour(RGBA& destColour)
     {
         if (mColourRangeStart != mColourRangeEnd)
         {
             // Randomise
-            //Real t = Math::UnitRandom();
-            destColour.r = mColourRangeStart.r + (Math::UnitRandom() * (mColourRangeEnd.r - mColourRangeStart.r));
-            destColour.g = mColourRangeStart.g + (Math::UnitRandom() * (mColourRangeEnd.g - mColourRangeStart.g));
-            destColour.b = mColourRangeStart.b + (Math::UnitRandom() * (mColourRangeEnd.b - mColourRangeStart.b));
-            destColour.a = mColourRangeStart.a + (Math::UnitRandom() * (mColourRangeEnd.a - mColourRangeStart.a));
+            ColourValue t(Math::UnitRandom(), Math::UnitRandom(), Math::UnitRandom(), Math::UnitRandom());
+            destColour = (mColourRangeStart + t * (mColourRangeEnd - mColourRangeStart)).getAsBYTE();
         }
         else
         {
-            destColour = mColourRangeStart;
+            destColour = mColourRangeStart.getAsBYTE();
         }
     }
     //-----------------------------------------------------------------------
@@ -335,6 +400,15 @@ namespace Ogre
             "The base direction of the emitter." , PT_VECTOR3),
             &msDirectionCmd);
 
+        dict->addParameter(ParameterDef("up", 
+            "The up vector of the emitter." , PT_VECTOR3),
+            &msUpCmd);
+
+        dict->addParameter(ParameterDef("direction_position_reference", 
+            "The reference position to calculate the direction of emitted particles "
+            "based on their position. Good for explosions and implosions (use negative velocity)" , PT_COLOURVALUE),
+            &msDirPositionRefCmd);
+
         dict->addParameter(ParameterDef("emission_rate", 
             "The number of particles emitted per second." , PT_REAL),
             &msEmissionRateCmd);
@@ -391,13 +465,13 @@ namespace Ogre
             "If set, after disabling an emitter will repeat (reenable) after this maximum number of seconds." , PT_REAL),
             &msMaxRepeatDelayCmd);
 
-		dict->addParameter(ParameterDef("name", 
-			"This is the name of the emitter" , PT_STRING),
-			&msNameCmd);
-		
-		dict->addParameter(ParameterDef("emit_emitter", 
-			"If set, this emitter will emit other emitters instead of visual particles" , PT_STRING),
-			&msEmittedEmitterCmd);
+        dict->addParameter(ParameterDef("name", 
+            "This is the name of the emitter" , PT_STRING),
+            &msNameCmd);
+        
+        dict->addParameter(ParameterDef("emit_emitter", 
+            "If set, this emitter will emit other emitters instead of visual particles" , PT_STRING),
+            &msEmittedEmitterCmd);
     }
     //-----------------------------------------------------------------------
     Real ParticleEmitter::getParticleVelocity(void) const
@@ -417,11 +491,13 @@ namespace Ogre
     //-----------------------------------------------------------------------
     void ParticleEmitter::setMinParticleVelocity(Real min)
     {
+        assert(std::isfinite(min));
         mMinSpeed = min;
     }
     //-----------------------------------------------------------------------
     void ParticleEmitter::setMaxParticleVelocity(Real max)
     {
+        assert(std::isfinite(max));
         mMaxSpeed = max;
     }
     //-----------------------------------------------------------------------
@@ -608,31 +684,23 @@ namespace Ogre
     ParticleEmitterFactory::~ParticleEmitterFactory()
     {
         // Destroy all emitters
-        std::vector<ParticleEmitter*>::iterator i;
-        for (i = mEmitters.begin(); i != mEmitters.end(); ++i)
+        for (auto& e : mEmitters)
         {
-            OGRE_DELETE (*i);
+            OGRE_DELETE e;
         }
             
         mEmitters.clear();
-
     }
     //-----------------------------------------------------------------------
     void ParticleEmitterFactory::destroyEmitter(ParticleEmitter* e)        
     {
-        std::vector<ParticleEmitter*>::iterator i;
-        for (i = mEmitters.begin(); i != mEmitters.end(); ++i)
-        {
-            if ((*i) == e)
-            {
-                mEmitters.erase(i);
-                OGRE_DELETE e;
-                break;
-            }
+        auto i = std::find(std::begin(mEmitters), std::end(mEmitters), e);
+        if (i != std::end(mEmitters)) {
+            mEmitters.erase(i);
+            OGRE_DELETE e;
         }
     }
 
     //-----------------------------------------------------------------------
-
 }
 
