@@ -297,12 +297,12 @@ namespace Ogre {
     //---------------------------------------------------------------------------------------------
     void RenderSystem::useCustomRenderSystemCapabilities(RenderSystemCapabilities* capabilities)
     {
-    if (mRealCapabilities != 0)
-    {
-      OGRE_EXCEPT(Exception::ERR_INTERNAL_ERROR, 
-          "Custom render capabilities must be set before the RenderSystem is initialised.",
-          "RenderSystem::useCustomRenderSystemCapabilities");
-    }
+        if (mRealCapabilities != 0)
+        {
+          OGRE_EXCEPT(Exception::ERR_INTERNAL_ERROR,
+              "Custom render capabilities must be set before the RenderSystem is initialised.",
+              "RenderSystem::useCustomRenderSystemCapabilities");
+        }
 
         mCurrentCapabilities = capabilities;
         mUseCustomCapabilities = true;
@@ -425,11 +425,14 @@ namespace Ogre {
         // Bind texture (may be blank)
         _setTexture(texUnit, true, tex);
 
+        _setSampler(texUnit, *tl.getSampler());
+
+        if(!getCapabilities()->hasCapability(RSC_FIXED_FUNCTION))
+            return;
+
         // Set texture coordinate set
         _setTextureCoordSet(texUnit, tl.getTextureCoordSet());
 
-        _setSampler(texUnit, *tl.getSampler());
-
         // Set blend modes
         // Note, colour before alpha is important
         _setTextureBlendMode(texUnit, tl.getColourBlendMode());
@@ -1001,6 +1004,16 @@ namespace Ogre {
         optFullScreen.immutable = false;
         mOptions[optFullScreen.name] = optFullScreen;
 
+        // Video mode possibilities, can be overwritten by actual values
+        ConfigOption optVideoMode;
+        optVideoMode.name = "Video Mode";
+        optVideoMode.possibleValues.push_back("1920 x 1080");
+        optVideoMode.possibleValues.push_back("1280 x 720");
+        optVideoMode.possibleValues.push_back("800 x 600");
+        optVideoMode.currentValue = optVideoMode.possibleValues.back();
+        optVideoMode.immutable = false;
+        mOptions[optVideoMode.name] = optVideoMode;
+
         ConfigOption optVSync;
         optVSync.name = "VSync";
         optVSync.immutable = false;
