@@ -31,6 +31,8 @@ THE SOFTWARE.
 #include "OgreLogManager.h"
 #include "OgreException.h"
 
+#define D3DFMT_INTZ ( (D3DFORMAT)MAKEFOURCC('I', 'N', 'T', 'Z') )
+
 namespace Ogre 
 {
     //---------------------------------------------------------------------
@@ -70,19 +72,10 @@ namespace Ogre
             return D3DTSS_TCI_PASSTHRU;
         case TEXCALC_ENVIRONMENT_MAP_REFLECTION:
             return D3DTSS_TCI_CAMERASPACEREFLECTIONVECTOR;
-        case TEXCALC_ENVIRONMENT_MAP_PLANAR:
-            if (caps.VertexProcessingCaps & D3DVTXPCAPS_TEXGEN_SPHEREMAP)
-            {
-                // Use sphere map if available
-                return D3DTSS_TCI_SPHEREMAP;
-            }
-            else
-            {
-                // If not, fall back on camera space reflection vector which isn't as good
-                return D3DTSS_TCI_CAMERASPACEREFLECTIONVECTOR;
-            }
         case TEXCALC_ENVIRONMENT_MAP_NORMAL:
             return D3DTSS_TCI_CAMERASPACENORMAL;
+        case TEXCALC_ENVIRONMENT_MAP_PLANAR:
+            // should be D3DTSS_TCI_CAMERASPACEPOSITION, but it has been like this since v0.12
         case TEXCALC_ENVIRONMENT_MAP:
             if (caps.VertexProcessingCaps & D3DVTXPCAPS_TEXGEN_SPHEREMAP)
             {
@@ -672,6 +665,8 @@ namespace Ogre
             return PF_DXT4;
         case D3DFMT_DXT5:
             return PF_DXT5;
+        case D3DFMT_INTZ:
+            return PF_DEPTH16;
         default:
             return PF_UNKNOWN;
         }
@@ -737,6 +732,8 @@ namespace Ogre
             return D3DFMT_DXT4;
         case PF_DXT5:
             return D3DFMT_DXT5;
+        case PF_DEPTH16:
+            return D3DFMT_INTZ;
         case PF_UNKNOWN:
         default:
             return D3DFMT_UNKNOWN;
