@@ -52,12 +52,12 @@ namespace Ogre {
         /**
             Get the render operation for this buffer 
         */
-        virtual void getRenderOperation(RenderOperation& op);
+        void getRenderOperation(RenderOperation& op) override;
 
         /**
             Update the contents of this vertex buffer by rendering
         */
-        virtual void update(SceneManager* sceneMgr);
+        void update(SceneManager* sceneMgr) override;
     protected:
         void reallocateBuffer(size_t index);
         void bindVerticesOutput(Pass* pass);
