@@ -108,53 +108,6 @@ namespace Ogre {
             // change back to fixed pipeline
             glUseProgramObjectARB(0);
         }
-    }
-    //---------------------------------------------------------------------
-    bool GLSLLinkProgramManager::completeParamSource(
-        const String& paramName,
-        const GpuConstantDefinitionMap* vertexConstantDefs, 
-        const GpuConstantDefinitionMap* geometryConstantDefs,
-        const GpuConstantDefinitionMap* fragmentConstantDefs,
-        GLUniformReference& refToUpdate)
-    {
-        if (vertexConstantDefs)
-        {
-            GpuConstantDefinitionMap::const_iterator parami = 
-                vertexConstantDefs->find(paramName);
-            if (parami != vertexConstantDefs->end())
-            {
-                refToUpdate.mSourceProgType = GPT_VERTEX_PROGRAM;
-                refToUpdate.mConstantDef = &(parami->second);
-                return true;
-            }
-
-        }
-        if (geometryConstantDefs)
-        {
-            GpuConstantDefinitionMap::const_iterator parami = 
-                geometryConstantDefs->find(paramName);
-            if (parami != geometryConstantDefs->end())
-            {
-                refToUpdate.mSourceProgType = GPT_GEOMETRY_PROGRAM;
-                refToUpdate.mConstantDef = &(parami->second);
-                return true;
-            }
-
-        }
-        if (fragmentConstantDefs)
-        {
-            GpuConstantDefinitionMap::const_iterator parami = 
-                fragmentConstantDefs->find(paramName);
-            if (parami != fragmentConstantDefs->end())
-            {
-                refToUpdate.mSourceProgType = GPT_FRAGMENT_PROGRAM;
-                refToUpdate.mConstantDef = &(parami->second);
-                return true;
-            }
-        }
-        return false;
-
-
     }
     //---------------------------------------------------------------------
     void GLSLLinkProgramManager::extractUniforms(uint programObject,
@@ -175,52 +128,22 @@ namespace Ogre {
         glGetObjectParameterivARB((GLhandleARB)programObject, GL_OBJECT_ACTIVE_UNIFORMS_ARB,
             &uniformCount);
 
+        const GpuConstantDefinitionMap* params[6] = { vertexConstantDefs, fragmentConstantDefs, geometryConstantDefs };
+
         // Loop over each of the active uniforms, and add them to the reference container
         // only do this for user defined uniforms, ignore built in gl state uniforms
         for (int index = 0; index < uniformCount; index++)
         {
-            GLint arraySize = 0;
+            GLint numActiveArrayElements = 0;
             GLenum glType;
             glGetActiveUniformARB((GLhandleARB)programObject, index, BUFFERSIZE, NULL,
-                &arraySize, &glType, uniformName);
-            // don't add built in uniforms
+                &numActiveArrayElements, &glType, uniformName);
             newGLUniformReference.mLocation = glGetUniformLocationARB((GLhandleARB)programObject, uniformName);
-            if (newGLUniformReference.mLocation >= 0)
-            {
-                // user defined uniform found, add it to the reference list
-                String paramName = String( uniformName );
 
-                // Current ATI drivers (Catalyst 7.2 and earlier) and older NVidia drivers will include all array elements as uniforms but we only want the root array name and location
-                // Also note that ATI Catalyst 6.8 to 7.2 there is a bug with glUniform that does not allow you to update a uniform array past the first uniform array element
-                // ie you can't start updating an array starting at element 1, must always be element 0.
-
-                // if the uniform name has a "[" in it then its an array element uniform.
-                String::size_type arrayStart = paramName.find('[');
-                if (arrayStart != String::npos)
-                {
-                    // if not the first array element then skip it and continue to the next uniform
-                    if (paramName.compare(arrayStart, paramName.size() - 1, "[0]") != 0) continue;
-                    paramName = paramName.substr(0, arrayStart);
-                }
-
-                // find out which params object this comes from
-                bool foundSource = completeParamSource(paramName,
-                        vertexConstantDefs, geometryConstantDefs, fragmentConstantDefs, newGLUniformReference);
-
-                // only add this parameter if we found the source
-                if (foundSource)
-                {
-                    assert(size_t (arraySize) == newGLUniformReference.mConstantDef->arraySize
-                            && "GL doesn't agree with our array size!");
-                    list.push_back(newGLUniformReference);
-                }
-
-                // Don't bother adding individual array params, they will be
-                // picked up in the 'parent' parameter can copied all at once
-                // anyway, individual indexes are only needed for lookup from
-                // user params
-            } // end if
-        } // end for
+            if(!validateParam(uniformName, numActiveArrayElements, params, newGLUniformReference))
+                continue;
+            list.push_back(newGLUniformReference);
+        }
 
     }
 }
