@@ -13,6 +13,7 @@ static const char *c_instancingTechniques[] =
     "Hardware Instancing Basic",
     "Hardware Instancing + VTF",
     "Limited Animation - Hardware Instancing + VTF",
+    "Automatic HW Instancing",
     "No Instancing"
 };
 
@@ -23,6 +24,7 @@ static const char *c_materialsTechniques[] =
     "Examples/Instancing/HWBasic/Robot",
     "Examples/Instancing/VTF/HW/Robot",
     "Examples/Instancing/VTF/HW/LUT/Robot",
+    "Examples/Instancing/HWBasic/Robot",
     "Examples/Instancing/RTSS/Robot"
 };
 
@@ -33,6 +35,7 @@ static const char *c_materialsTechniques_dq[] =
     "Examples/Instancing/HWBasic/Robot",
     "Examples/Instancing/VTF/HW/Robot_dq",
     "Examples/Instancing/VTF/HW/LUT/Robot_dq",
+    "Examples/Instancing/HWBasic/Robot",
     "Examples/Instancing/RTSS/Robot_dq"
 };
 
@@ -43,6 +46,7 @@ static const char *c_materialsTechniques_dq_two_weights[] =
     "Examples/Instancing/HWBasic/spine",
     "Examples/Instancing/VTF/HW/spine_dq_two_weights",
     "Examples/Instancing/VTF/HW/LUT/spine_dq_two_weights",
+    "Examples/Instancing/HWBasic/spine",
     "Examples/Instancing/RTSS/spine_dq_two_weights"
 };
 
@@ -95,7 +99,7 @@ bool Sample_NewInstancing::keyPressed(const KeyboardEvent& evt)
 
     //Switch to next instancing technique with space bar
     if (key == SDLK_SPACE && !mTrayMgr->isDialogVisible())
-        mTechniqueMenu->selectItem( (mTechniqueMenu->getSelectionIndex() + 1) % (NUM_TECHNIQUES+1) );
+        mTechniqueMenu->selectItem( (mTechniqueMenu->getSelectionIndex() + 1) % NUM_TECHNIQUES );
 
     return SdkSample::keyPressed(evt);
 }
@@ -108,11 +112,11 @@ void Sample_NewInstancing::setupContent()
     mViewport->setMaterialScheme(MSN_SHADERGEN);
     RTShader::ShaderGenerator& rtShaderGen = RTShader::ShaderGenerator::getSingleton();
     RTShader::RenderState* schemRenderState = rtShaderGen.getRenderState(MSN_SHADERGEN);
-    RTShader::SubRenderState* subRenderState = rtShaderGen.createSubRenderState("SGX_IntegratedPSSM3");
+    RTShader::SubRenderState* subRenderState = rtShaderGen.createSubRenderState(RTShader::SRS_INTEGRATED_PSSM3);
     schemRenderState->addTemplateSubRenderState(subRenderState);
 
     //Add the hardware skinning to the shader generator default render state
-    subRenderState = mShaderGenerator->createSubRenderState<RTShader::HardwareSkinning>();
+    subRenderState = mShaderGenerator->createSubRenderState(RTShader::SRS_HARDWARE_SKINNING);
     schemRenderState->addTemplateSubRenderState(subRenderState);
 
     // increase max bone count for higher efficiency
@@ -194,7 +198,6 @@ void Sample_NewInstancing::setupLighting()
 //------------------------------------------------------------------------------
 void Sample_NewInstancing::switchInstancingTechnique()
 {
-    //mInstancingTechnique = (mInstancingTechnique+1) % (NUM_TECHNIQUES+1);
     mInstancingTechnique = mTechniqueMenu->getSelectionIndex();
 
     if( mCurrentManager )
@@ -209,7 +212,7 @@ void Sample_NewInstancing::switchInstancingTechnique()
         return;
     }
 
-    if( mInstancingTechnique < NUM_TECHNIQUES )
+    if( mInstancingTechnique < NUM_IM_TECHNIQUES )
     {
         //Instancing
 
@@ -255,7 +258,7 @@ void Sample_NewInstancing::switchInstancingTechnique()
     else
     {
         //Non-instancing
-        createEntities();
+        createEntities(mInstancingTechnique);
 
         //Hide GUI features available only to instancing
         mCurrentManager = 0;
@@ -276,7 +279,7 @@ void Sample_NewInstancing::switchInstancingTechnique()
     }
     else
         mSetStatic->hide();
-    if( mInstancingTechnique < NUM_TECHNIQUES)
+    if( mInstancingTechnique < NUM_IM_TECHNIQUES)
     {
         mUseSceneNodes->show();
     }
@@ -314,7 +317,7 @@ void Sample_NewInstancing::switchSkinningTechnique(int index)
 }
 
 //------------------------------------------------------------------------------
-void Sample_NewInstancing::createEntities()
+void Sample_NewInstancing::createEntities(int technique)
 {
     std::mt19937 rng;
     for( int i=0; i<NUM_INST_ROW * NUM_INST_COLUMN; ++i )
@@ -323,15 +326,18 @@ void Sample_NewInstancing::createEntities()
         //a. To prove we can (runs without modification! :-) )
         //b. Make a fair comparison
         Entity *ent = mSceneMgr->createEntity( c_meshNames[mCurrentMesh] );
-        ent->setMaterialName( mCurrentMaterialSet[NUM_TECHNIQUES] );
+        ent->setMaterialName( mCurrentMaterialSet[technique] );
         mEntities.push_back( ent );
 
+        if(technique == NUM_IM_TECHNIQUES)
+            continue;
+
         //Get the animation
         AnimationState *anim = ent->getAnimationState( "Walk" );
         if (mAnimations.insert( anim ).second)
         {
             anim->setEnabled( true );
-            anim->addTime( float(rng())/float(rng.max()) * 10 ); //Random start offset
+            anim->addTime( double(rng())/rng.max() * 10 ); //Random start offset
         }
     }
 }
@@ -354,11 +360,11 @@ void Sample_NewInstancing::createInstancedEntities()
                 //Get the animation
                 AnimationState *anim = ent->getAnimationState( "Walk" );
                 anim->setEnabled( true );
-                anim->addTime( float(rng())/float(rng.max()) * 10); //Random start offset
+                anim->addTime( double(rng())/rng.max() * 10); //Random start offset
                 mAnimations.insert( anim );
             }
 
-            if ((mInstancingTechnique < NUM_TECHNIQUES) && (!mUseSceneNodes->isChecked()))
+            if ((mInstancingTechnique < NUM_IM_TECHNIQUES) && (!mUseSceneNodes->isChecked()))
             {
                 mMovedInstances.push_back( ent );
                 ent->setOrientation(Quaternion(Radian(float(orng())/float(orng.max()) * 10 * Math::PI), Vector3::UNIT_Y));
@@ -381,11 +387,11 @@ void Sample_NewInstancing::createSceneNodes()
         for( int j=0; j<NUM_INST_COLUMN; ++j )
         {
             int idx = i * NUM_INST_COLUMN + j;
-            if ((mInstancingTechnique >= NUM_TECHNIQUES) || (mUseSceneNodes->isChecked()))
+            if ((mInstancingTechnique >= NUM_IM_TECHNIQUES) || (mUseSceneNodes->isChecked()))
             {
                 SceneNode *sceneNode = rootNode->createChildSceneNode();
                 sceneNode->attachObject( mEntities[idx] );
-                sceneNode->yaw( Radian( float(rng())/float(rng.max()) * 10 * Math::PI )); //Random orientation
+                sceneNode->yaw( Radian( double(rng())/rng.max() * 10 * Math::PI )); //Random orientation
                 sceneNode->setPosition( mEntities[idx]->getBoundingRadius() * (i - NUM_INST_ROW * 0.5f), 0,
                     mEntities[idx]->getBoundingRadius() * (j - NUM_INST_COLUMN * 0.5f) );
                 mSceneNodes.push_back( sceneNode );
@@ -410,7 +416,7 @@ void Sample_NewInstancing::clearScene()
             sceneNode->detachAllObjects();
             sceneNode->getParentSceneNode()->removeAndDestroyChild( sceneNode );
         }
-        if( mInstancingTechnique == NUM_TECHNIQUES )
+        if( mInstancingTechnique >= NUM_IM_TECHNIQUES )
             mSceneMgr->destroyEntity( (*itor)->getName() );
         else
             mSceneMgr->destroyInstancedEntity( static_cast<InstancedEntity*>(*itor) );
@@ -581,7 +587,7 @@ void Sample_NewInstancing::setupGUI()
 {
     mTechniqueMenu = mTrayMgr->createLongSelectMenu(
         TL_TOPLEFT, "TechniqueSelectMenu", "Technique", 450, 350, 5);
-    for( int i=0; i<NUM_TECHNIQUES+1; ++i )
+    for( int i=0; i<NUM_TECHNIQUES; ++i )
     {
         String text = c_instancingTechniques[i];
         if( !mSupportedTechniques[i] )
@@ -684,8 +690,11 @@ void Sample_NewInstancing::sliderMoved( Slider* slider )
 
 void Sample_NewInstancing::checkHardwareSupport()
 {
+    //Non instancing is always supported
+    mSupportedTechniques.fill(true);
+
     //Check Technique support
-    for( int i=0; i<NUM_TECHNIQUES; ++i )
+    for( int i=0; i<NUM_IM_TECHNIQUES; ++i )
     {
         InstanceManager::InstancingTechnique technique;
         switch( i )
@@ -709,7 +718,4 @@ void Sample_NewInstancing::checkHardwareSupport()
 
         mSupportedTechniques[i] = numInstances > 0;
     }
-
-    //Non instancing is always supported
-    mSupportedTechniques[NUM_TECHNIQUES] = true;
 }
