@@ -64,10 +64,27 @@ TEST_F(CameraTests,customProjectionMatrix)
     std::vector<Vector3> corners(cam.getWorldSpaceCorners(), cam.getWorldSpaceCorners() + 8);
     RealRect extents = cam.getFrustumExtents();
     cam.setCustomProjectionMatrix(true, cam.getProjectionMatrix());
-    for(int j = 0; j < 8; j++)
-        EXPECT_EQ(corners[j], cam.getWorldSpaceCorners()[j]);
+    for(int j = 0; j < 8; j++) {
+        for(int k = 0; k < 3; k++) {
+            if(typeid(corners[j]) == typeid(float))
+                EXPECT_FLOAT_EQ(corners[j][k], cam.getWorldSpaceCorners()[j][k]);
+            else
+                EXPECT_DOUBLE_EQ(corners[j][k], cam.getWorldSpaceCorners()[j][k]);
+        }
+    }
+
+    if(typeid(Ogre::Real) == typeid(float)) {
+        EXPECT_FLOAT_EQ(extents.bottom, cam.getFrustumExtents().bottom);
+        EXPECT_FLOAT_EQ(extents.top, cam.getFrustumExtents().top);
+        EXPECT_FLOAT_EQ(extents.left, cam.getFrustumExtents().left);
+        EXPECT_FLOAT_EQ(extents.right, cam.getFrustumExtents().right);
+    } else {
+        EXPECT_DOUBLE_EQ(extents.bottom, cam.getFrustumExtents().bottom);
+        EXPECT_DOUBLE_EQ(extents.top, cam.getFrustumExtents().top);
+        EXPECT_DOUBLE_EQ(extents.left, cam.getFrustumExtents().left);
+        EXPECT_DOUBLE_EQ(extents.right, cam.getFrustumExtents().right);
+    }
 
-    EXPECT_EQ(extents, cam.getFrustumExtents());
 }
 
 TEST(Root,shutdown)
@@ -103,9 +120,9 @@ static void createRandomEntityClones(Entity* ent, size_t cloneCount, const Vecto
         SceneNode* node = mgr->createSceneNode();
         // Random translate.
         Vector3 nodePos = max - min;
-        nodePos.x *= float(rng())/rng.max();
-        nodePos.y *= float(rng())/rng.max();
-        nodePos.z *= float(rng())/rng.max();
+        nodePos.x *= double(rng())/rng.max();
+        nodePos.y *= double(rng())/rng.max();
+        nodePos.z *= double(rng())/rng.max();
         nodePos += min;
         node->setPosition(nodePos);
         mgr->getRootSceneNode()->addChild(node);
@@ -120,7 +137,7 @@ struct SceneQueryTest : public RootWithoutRenderSystemFixture {
     Camera* mCamera;
     SceneNode* mCameraNode;
 
-    void SetUp() {
+    void SetUp() override {
         RootWithoutRenderSystemFixture::SetUp();
 
         mSceneMgr = mRoot->createSceneManager();
@@ -287,9 +304,50 @@ TEST(Image, Combine)
     ASSERT_TRUE(!memcmp(combined.getData(), ref.getData(), ref.getSize()));
 }
 
+TEST(Image, Compressed)
+{
+    Root root;
+    ConfigFile cf;
+    cf.load(FileSystemLayer(OGRE_VERSION_NAME).getConfigFilePath("resources.cfg"));
+    auto testPath = cf.getSettings("Tests").begin()->second;
+
+    Image img;
+#if OGRE_NO_PVRTC_CODEC == 0
+    // 2bpp
+    img.load(Root::openFileStream(testPath+"/ogreborderUp_pvr2.pvr"), "pvr");
+    EXPECT_EQ(img.getFormat(), PF_PVRTC_RGB2);
+    // 2bpp alpha
+    img.load(Root::openFileStream(testPath+"/ogreborderUp_pvr2a.pvr"), "pvr");
+    EXPECT_EQ(img.getFormat(), PF_PVRTC_RGBA2);
+    // 4bpp
+    img.load(Root::openFileStream(testPath+"/ogreborderUp_pvr4.pvr"), "pvr");
+    EXPECT_EQ(img.getFormat(), PF_PVRTC_RGB4);
+    // 4 bpp alpha
+    img.load(Root::openFileStream(testPath+"/ogreborderUp_pvr4a.pvr"), "pvr");
+    EXPECT_EQ(img.getFormat(), PF_PVRTC_RGBA4);
+#endif
+
+#if OGRE_NO_ETC_CODEC == 0
+    img.load(Root::openFileStream(testPath+"/Texture.pkm"), "pkm");
+    EXPECT_EQ(img.getFormat(), PF_ETC2_RGB8);
+    img.load(Root::openFileStream(testPath+"/etc2-rgba8.ktx"), "ktx");
+    EXPECT_EQ(img.getFormat(), PF_ETC2_RGBA8);
+#endif
+
+#if OGRE_NO_ASTC_CODEC == 0
+    img.load(Root::openFileStream(testPath+"/Earth-Color10x6.astc"), "astc");
+    EXPECT_EQ(img.getFormat(), PF_ASTC_RGBA_10X6_LDR);
+#endif
+
+#if OGRE_NO_DDS_CODEC == 0
+    img.load(Root::openFileStream(testPath+"/ogreborderUp_dxt3.dds"), "dds");
+    EXPECT_EQ(img.getFormat(), PF_BYTE_RGBA); // no RenderSystem available, will decompress
+#endif
+}
+
 struct UsePreviousResourceLoadingListener : public ResourceLoadingListener
 {
-    bool resourceCollision(Resource *resource, ResourceManager *resourceManager) { return false; }
+    bool resourceCollision(Resource *resource, ResourceManager *resourceManager) override { return false; }
 };
 
 typedef RootWithoutRenderSystemFixture ResourceLoading;
@@ -322,7 +380,7 @@ TEST_F(ResourceLoading, CollsionUseExisting)
 
 struct DeletePreviousResourceLoadingListener : public ResourceLoadingListener
 {
-    bool resourceCollision(Resource* resource, ResourceManager* resourceManager)
+    bool resourceCollision(Resource* resource, ResourceManager* resourceManager) override
     {
         resourceManager->remove(resource->getName(), resource->getGroup());
         return true;
@@ -448,4 +506,39 @@ TEST(MaterialLoading, LateShadowCaster)
     tech->_load();
 
     EXPECT_TRUE(tech->getShadowCasterMaterial());
+}
+
+TEST(Light, AnimableValue)
+{
+    Light l;
+
+    l.setDiffuseColour(0, 0, 0);
+    auto diffuseColour = l.createAnimableValue("diffuseColour");
+    diffuseColour->applyDeltaValue(ColourValue(1, 2, 3, 0));
+    EXPECT_EQ(l.getDiffuseColour(), ColourValue(1, 2, 3));
+
+    l.setSpecularColour(0, 0, 0);
+    auto specularColour = l.createAnimableValue("specularColour");
+    specularColour->applyDeltaValue(ColourValue(1, 2, 3, 0));
+    EXPECT_EQ(l.getSpecularColour(), ColourValue(1, 2, 3));
+
+    l.setAttenuation(0, 0, 0, 0);
+    auto attenuation = l.createAnimableValue("attenuation");
+    attenuation->applyDeltaValue(Vector4(1, 2, 3, 4));
+    EXPECT_EQ(l.getAttenuation(), Vector4f(1, 2, 3, 4));
+
+    l.setSpotlightInnerAngle(Radian(0));
+    auto spotlightInner = l.createAnimableValue("spotlightInner");
+    spotlightInner->applyDeltaValue(Real(1));
+    EXPECT_EQ(l.getSpotlightInnerAngle(), Radian(1));
+
+    l.setSpotlightOuterAngle(Radian(0));
+    auto spotlightOuter = l.createAnimableValue("spotlightOuter");
+    spotlightOuter->applyDeltaValue(Real(1));
+    EXPECT_EQ(l.getSpotlightOuterAngle(), Radian(1));
+
+    l.setSpotlightFalloff(0);
+    auto spotlightFalloff = l.createAnimableValue("spotlightFalloff");
+    spotlightFalloff->applyDeltaValue(Real(1));
+    EXPECT_EQ(l.getSpotlightFalloff(), 1);
 }
\ No newline at end of file
