@@ -43,11 +43,11 @@ class _OgreSampleClassExport PlayPen_ManualLOD : public VisualTest
 public:
 
     PlayPen_ManualLOD();
-    bool frameStarted(const FrameEvent& evt);
+    bool frameStarted(const FrameEvent& evt) override;
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
     String getLODMesh();
 
     AnimationState* mAnimation;
@@ -78,7 +78,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -89,13 +89,13 @@ class _OgreSampleClassExport PlayPen_ProjectSphere : public VisualTest
 public:
 
     PlayPen_ProjectSphere();
-    bool frameStarted(const FrameEvent& evt);
+    bool frameStarted(const FrameEvent& evt) override;
 
 protected:
 
     Sphere* mProjectionSphere;
     ManualObject* mScissorRect;
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -106,8 +106,8 @@ class _OgreSampleClassExport PlayPen_CameraSetDirection : public VisualTest
 public:
 
     PlayPen_CameraSetDirection();
-    void buttonHit(OgreBites::Button* button);
-    void checkBoxToggled(OgreBites::CheckBox* box);
+    void buttonHit(OgreBites::Button* button) override;
+    void checkBoxToggled(OgreBites::CheckBox* box) override;
 
 protected:
 
@@ -115,7 +115,7 @@ protected:
     bool mUseFixedYaw;
     SceneNode* mParentNode;
     Vector3 mFocus;
-    void setupContent();
+    void setupContent() override;
     void toggleParentNode();
     void toggleFixedYaw();
     void track();
@@ -129,11 +129,11 @@ class _OgreSampleClassExport PlayPen_MorphAnimationWithNormals : public VisualTe
 public:
 
     PlayPen_MorphAnimationWithNormals();
-    bool frameStarted(const FrameEvent& evt);
+    bool frameStarted(const FrameEvent& evt) override;
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
     AnimationState* mAnimations[2];
 
 };
@@ -145,11 +145,11 @@ class _OgreSampleClassExport PlayPen_MorphAnimationWithoutNormals : public Visua
 public:
 
     PlayPen_MorphAnimationWithoutNormals();
-    bool frameStarted(const FrameEvent& evt);
+    bool frameStarted(const FrameEvent& evt) override;
     
 protected:
 
-    void setupContent();
+    void setupContent() override;
     AnimationState* mAnimations[2];
 
 };
@@ -161,11 +161,11 @@ class _OgreSampleClassExport PlayPen_PoseAnimationWithNormals : public VisualTes
 public:
 
     PlayPen_PoseAnimationWithNormals();
-    bool frameStarted(const FrameEvent& evt);
+    bool frameStarted(const FrameEvent& evt) override;
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
     AnimationState* mAnimations[2];
 
 };
@@ -177,11 +177,11 @@ class _OgreSampleClassExport PlayPen_PoseAnimationWithoutNormals : public Visual
 public:
 
     PlayPen_PoseAnimationWithoutNormals();
-    bool frameStarted(const FrameEvent& evt);
+    bool frameStarted(const FrameEvent& evt) override;
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
     AnimationState* mAnimations[2];
 
 };
@@ -193,11 +193,11 @@ class _OgreSampleClassExport PlayPen_SceneNodeTracking : public VisualTest
 public:
 
     PlayPen_SceneNodeTracking();
-    bool frameStarted(const FrameEvent& evt);
+    bool frameStarted(const FrameEvent& evt) override;
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
     AnimationState* mAnimState;
 
 };
@@ -216,7 +216,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
     StencilOpQueueListener* mStencilListener;
 
 };
@@ -230,7 +230,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -244,7 +244,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -258,7 +258,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -270,14 +270,14 @@ public:
 
     PlayPen_Bsp();
 
-    StringVector getRequiredPlugins()
+    StringVector getRequiredPlugins() override
     {
         StringVector names;
         names.push_back("BSP Scene Manager");
         return names;
     }
 
-    void createSceneManager()
+    void createSceneManager() override
     {
         mSceneMgr = mRoot->createSceneManager("BspSceneManager");
 #ifdef OGRE_BUILD_COMPONENT_RTSHADERSYSTEM
@@ -287,7 +287,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -301,7 +301,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -315,7 +315,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -334,8 +334,8 @@ public:
 
 protected:
 
-    void setupContent();
-    virtual void cleanupContent();
+    void setupContent() override;
+    void cleanupContent() override;
 
     RefractionTextureListener* mRefractionListener;
     ReflectionTextureListener* mReflectionListener;
@@ -352,7 +352,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -366,7 +366,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -380,7 +380,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -394,7 +394,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -408,7 +408,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -422,7 +422,7 @@ public:
     bool isScreenshotFrame(int frame) override;
 
 protected:
-    void setupContent();
+    void setupContent() override;
 };
 
 //------------------------------------------------------------------------------
@@ -435,7 +435,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -449,7 +449,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -463,7 +463,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -477,8 +477,8 @@ public:
 
 protected:
 
-    void setupContent();
-    void cleanupContent();
+    void setupContent() override;
+    void cleanupContent() override;
 
 };
 
@@ -492,7 +492,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -506,7 +506,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -520,8 +520,8 @@ public:
 
 protected:
 
-    void setupContent();
-    void cleanupContent();
+    void setupContent() override;
+    void cleanupContent() override;
 
 };
 
@@ -532,12 +532,12 @@ class _OgreSampleClassExport PlayPen_CompositorTechniqueSwitch : public VisualTe
 public:
 
     PlayPen_CompositorTechniqueSwitch();
-    bool frameStarted(const FrameEvent& evt);
+    bool frameStarted(const FrameEvent& evt) override;
 
 protected:
 
-    void setupContent();
-    void cleanupContent();
+    void setupContent() override;
+    void cleanupContent() override;
 
     CompositorInstance* mCompositorToSwitch;
     size_t mCompositorIndex;
@@ -556,7 +556,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -568,14 +568,14 @@ public:
 
     PlayPen_InfiniteAAB();
 
-    StringVector getRequiredPlugins()
+    StringVector getRequiredPlugins() override
     {
         StringVector names;
         names.push_back("BSP Scene Manager");
         return names;
     }
 
-    void createSceneManager()
+    void createSceneManager() override
     {
         mSceneMgr = mRoot->createSceneManager("BspSceneManager");
 #ifdef OGRE_BUILD_COMPONENT_RTSHADERSYSTEM
@@ -585,8 +585,8 @@ public:
 
 protected:
 
-    void setupContent();
-    void cleanupContent();
+    void setupContent() override;
+    void cleanupContent() override;
 
 };
 
@@ -600,7 +600,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -614,7 +614,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -625,11 +625,11 @@ class _OgreSampleClassExport PlayPen_ReloadResources : public VisualTest
 public:
 
     PlayPen_ReloadResources();
-    bool frameStarted(const FrameEvent& evt);
+    bool frameStarted(const FrameEvent& evt) override;
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
     Real mReloadTimer;
 
 };
@@ -644,7 +644,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -658,7 +658,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -672,7 +672,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -686,7 +686,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -700,7 +700,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -714,7 +714,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -728,7 +728,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -742,7 +742,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -756,7 +756,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -770,7 +770,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -782,7 +782,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -794,7 +794,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -808,7 +808,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -822,7 +822,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -836,7 +836,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -850,7 +850,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -864,7 +864,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -878,7 +878,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -892,7 +892,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -906,7 +906,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -920,7 +920,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -934,7 +934,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -948,7 +948,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -962,7 +962,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -976,7 +976,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -990,7 +990,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1001,11 +1001,11 @@ class _OgreSampleClassExport PlayPen_ManualBoneMovement : public VisualTest
 public:
 
     PlayPen_ManualBoneMovement();
-    bool frameStarted(const FrameEvent& evt);
+    bool frameStarted(const FrameEvent& evt) override;
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
     Bone* mBone;
 
 };
@@ -1020,7 +1020,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1034,7 +1034,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1048,7 +1048,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1062,7 +1062,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1076,7 +1076,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1088,7 +1088,7 @@ public:
 
     PlayPen_VertexTexture();
 
-    virtual void testCapabilities(const RenderSystemCapabilities* caps)
+    void testCapabilities(const RenderSystemCapabilities* caps) override
     {
         if(!caps->isShaderProfileSupported("hlsl") && !caps->isShaderProfileSupported("glsl"))
             OGRE_EXCEPT(Exception::ERR_NOT_IMPLEMENTED, "not implemented");
@@ -1096,7 +1096,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1110,7 +1110,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1124,7 +1124,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1138,7 +1138,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1152,8 +1152,8 @@ public:
 
 protected:
 
-    void setupContent();
-    void cleanupContent();
+    void setupContent() override;
+    void cleanupContent() override;
 
 };
 
@@ -1167,8 +1167,8 @@ public:
 
 protected:
 
-    void setupContent();
-    void cleanupContent();
+    void setupContent() override;
+    void cleanupContent() override;
 
 };
 
@@ -1182,7 +1182,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1196,7 +1196,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1210,7 +1210,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1224,7 +1224,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1235,11 +1235,11 @@ class _OgreSampleClassExport PlayPen_16Textures : public VisualTest
 public:
 
     PlayPen_16Textures();
-    void testCapabilities(const Ogre::RenderSystemCapabilities* caps);
+    void testCapabilities(const Ogre::RenderSystemCapabilities* caps) override;
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1253,7 +1253,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1267,7 +1267,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1278,11 +1278,11 @@ class _OgreSampleClassExport PlayPen_ReinitialiseEntityAlteredMesh : public Visu
 public:
 
     PlayPen_ReinitialiseEntityAlteredMesh();
-    bool frameStarted(const FrameEvent& evt);
+    bool frameStarted(const FrameEvent& evt) override;
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
     
     Mesh* mUpdate;
     Real mTimer;
@@ -1299,7 +1299,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1313,7 +1313,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1327,7 +1327,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1341,8 +1341,8 @@ public:
 
 protected:
 
-    void setupContent();
-    void cleanupContent();
+    void setupContent() override;
+    void cleanupContent() override;
 
 };
 
@@ -1356,8 +1356,8 @@ public:
 
 protected:
 
-    void setupContent();
-    void cleanupContent();
+    void setupContent() override;
+    void cleanupContent() override;
 
 };
 
@@ -1368,11 +1368,11 @@ class _OgreSampleClassExport PlayPen_GeometryShaders : public VisualTest
 public:
 
     PlayPen_GeometryShaders();
-    void testCapabilities(const Ogre::RenderSystemCapabilities* caps);
+    void testCapabilities(const Ogre::RenderSystemCapabilities* caps) override;
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1386,7 +1386,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1400,8 +1400,8 @@ public:
 
 protected:
 
-    void setupContent();
-    void cleanupContent();
+    void setupContent() override;
+    void cleanupContent() override;
 
 };
 
@@ -1415,7 +1415,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 //------------------------------------------------------------------------------
@@ -1428,7 +1428,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 //------------------------------------------------------------------------------
@@ -1441,7 +1441,7 @@ public:
 
 protected:
     std::unique_ptr<MovablePlane> movablePlane;
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1455,7 +1455,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
     void createMeshEntity(String group, Vector3 pos);
 
 };
@@ -1469,7 +1469,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 //------------------------------------------------------------------------------
@@ -1482,7 +1482,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1496,7 +1496,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1510,7 +1510,7 @@ public:
 
 protected:
 
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1524,67 +1524,7 @@ public:
 
 protected:
 
-    void setupContent();
-
-};
-
-//------------------------------------------------------------------------------
-/** Tests 4 bit per pixel PVR textures */
-class _OgreSampleClassExport PlayPen_4bppPVR : public VisualTest
-{
-public:
-
-    PlayPen_4bppPVR();
-    void testCapabilities(const Ogre::RenderSystemCapabilities* caps);
-
-protected:
-
-    void setupContent();
-
-};
-
-//------------------------------------------------------------------------------
-/** Tests 4 bit per pixel PVR textures w/ alpha */
-class _OgreSampleClassExport PlayPen_4bppAlphaPVR : public VisualTest
-{
-public:
-
-    PlayPen_4bppAlphaPVR();
-    void testCapabilities(const Ogre::RenderSystemCapabilities* caps);
-
-protected:
-
-    void setupContent();
-
-};
-
-//------------------------------------------------------------------------------
-/** Tests 2 bit per pixel PVR textures */
-class _OgreSampleClassExport PlayPen_2bppPVR : public VisualTest
-{
-public:
-
-    PlayPen_2bppPVR();
-    void testCapabilities(const Ogre::RenderSystemCapabilities* caps);
-
-protected:
-
-    void setupContent();
-
-};
-
-//------------------------------------------------------------------------------
-/** Tests 2 bit per pixel PVR textures w/ alpha */
-class _OgreSampleClassExport PlayPen_2bppAlphaPVR : public VisualTest
-{
-public:
-
-    PlayPen_2bppAlphaPVR();
-    void testCapabilities(const Ogre::RenderSystemCapabilities* caps);
-
-protected:
-
-    void setupContent();
+    void setupContent() override;
 
 };
 
@@ -1594,7 +1534,7 @@ public:
     PlayPen_BillboardText();
 
 protected:
-    void setupContent();
+    void setupContent() override;
 };
 
 class _OgreSampleClassExport PlayPen_PBR : public OgreBites::SdkSample
@@ -1603,8 +1543,8 @@ public:
     PlayPen_PBR();
 
 protected:
-    void setupContent();
-    void unloadResources();
+    void setupContent() override;
+    void unloadResources() override;
 };
 //------------------------------------------------------------------------------
 
